@@ -30,10 +30,11 @@
 
 Awards::Awards()
 {
-    //qDebug() << "Awards::Awards"  << endl;
+   //qDebug() << "Awards::Awards"  << endl;
     world = new World();
     dataProxy = new DataProxy_SQLite();
     dxMarathon = new DXMarathon();
+    util = new Utilities();
     //world->create();
 
     //newOneColor = Qt::green;
@@ -64,7 +65,7 @@ void Awards::setAwardDXCC(const int _qsoId)
     //qDebug() << "Awards::setAwardDXCC: _qsoId: " << QString::number(_qsoId) << endl;
     QString stringQuery;
     QSqlQuery query;
-    int nameCol;
+    //int nameCol;
     QString _ln;
     bool sqlOK;
     //bool __confirmed = dataProxy->isQSLReceived(_qsoId);
@@ -191,14 +192,12 @@ int Awards::getDXCCWorked(const int _logNumber)
             //qDebug() << "Awards::getDXCCWorked: 0" << endl;
             return 0;
         }
-
     }
     else
     {
         //qDebug() << "Awards::getDXCCWorked: Query error" << endl;
         return 0;
     }
-
 }
 
 int Awards::getDXCCConfirmed(const int _logNumber)
@@ -278,25 +277,44 @@ int Awards::getWAZConfirmed(const int _logNumber)
     }
 }
 
+bool Awards::isThisSpotConfirmed(const QStringList _qs)
+{
 
+    if (getDXStatus(_qs) == 13)
+    {
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+
+}
 int Awards::getDXStatus (const QStringList _qs)
 {
 
-//qDebug() << "Awards::getDXStatus: Call: " << _qs.at(0) << "/ Band: " << _qs.at(1) << "/ Mode: " << _qs.at(2)  << "/ Log: " << _qs.at(3)  <<  endl;
+    //qDebug() << "Awards::getDXStatus: Call: " << _qs.at(0) << "/ Band: " << _qs.at(1) << "/ Mode: " << _qs.at(2)  << "/ Log: " << _qs.at(3)  <<  endl;
 // Receives:  QStringList _qs;
 //_qs << QRZ << BandId << << ModeId << lognumber;
 
-/*
--1 - Error.
-0 - New one.
-1 - worked in this mode, not this band                              - newOneColor       ( mode=-1=> 0/newOneColor )
-2 - worked in this band, not this mode                              - neededColor       ( mode=-1=> 3/neededColor )
-3 - worked in this band and mode                                    - neededColor       ( mode=-1=> 3/neededColor )
-4 - confirmed in this mode, not worked in this band                 - workedColor       ( mode=-1=> 0/newOneColor )
-5 - confirmed in this band, not worked in this mode                 - neededColor       ( mode=-1=> 8/confirmedColor )
-6 - confirmed in this mode, not confirmed, but worked in this band  - workedColor       ( mode=-1=> 3/neededColor )
-7 - confirmed in this band, not confirmed, but worked in this mode  - workedColor       ( mode=-1=> 8/confirmedColor )
-8 - confirmed in this band and mode                                 - confirmedColor    ( mode=-1=> 8/confirmedColor )
+/*                                                                                                                  Not mode
+    -1 - Error.                                                                                     - ERROR     - ERROR
+ 0  -   New one                                                                                 - New One       - New One       -   0
+ 1  -   Worked but not in this band nor this mode                                               - Needed One    - Needed One    -   1
+ 2  -   Worked in this band, not this mode                                                      - Needed One    - Worked One    -   3
+ 3  -   Worked in this band and in this mode                                                    - Worked One    - Worked One    -   3
+ 4  -   Worked in this mode, not this band                                                      - Needed One    - Needed One    -   1
+
+ 5  -   Confirmed in another band/mode but not worked in this band nor this mode                - Needed One    - Needed One    -   1
+ 6  -   Confirmed in another band/mode but just worked in this band and not in this mode        - Needed One    - Worked One    -   3
+ 7  -   Confirmed in another band/mode but just worked in this mode and not in this band        - Needed One    - Needed One    -   1
+ 8  -   Confirmed in another band/mode but just worked in this band and mode                    - Worked One    - Worked One    -   3
+ 9  -   Confirmed in this mode, but not worked this band                                        - Needed One    - Needed One    -   1
+10  -   Confirmed in this mode, but worked this band                                            - Worked One    - Worked One    -   3
+11  -   Confirmed in this band but not worked in this mode                                      - Needed One    - Confirmed One -   13
+12  -   Confirmed in this band but worked in this mode                                          - Worked One    - Confirmed One -   13
+13  -   Confirmed in this band and mode                                                         - Confirmed One - Confirmed One -   13
+
 */
 
 /*
@@ -311,77 +329,202 @@ int Awards::getDXStatus (const QStringList _qs)
     {
         return -1;
     }
-    int errorCode = 0;
+
+    //int errorCode = 0;
 
     int _band = _qs.at(1).toInt();
     int _mode = _qs.at(2).toInt();
     int _logNumber = _qs.at(3).toInt();
     int dxccEntity = world->getQRZARRLId(_qs.at(0) );
+    if (dxccEntity<=0)
+    {
+        return -1;
+    }
 
-    //qDebug() << "Awards::getDXStatus: dxccEntity: " << QString::number(dxccEntity) << endl;
+   //qDebug() << "Awards::getDXStatus: dxccEntity: " << QString::number(dxccEntity) << endl;
 
 
     bool checkingMode = true;
     if (_mode==-1)
     {
         checkingMode = false;
-        //qDebug() << "Awards::getDXStatus: checkingMode = FALSE" << endl;
+       //qDebug() << "Awards::getDXStatus: checkingMode = FALSE" << endl;
+    }
+    // dxccStatusMode(const int _ent, const int _mode, const int _logNumber) //-1 error / 0 Not worked / 1 worked / 2 confirmed
+
+    int wb = dxccStatusBand(dxccEntity, _band, _logNumber); //-1 error / 0 Not worked / 1 worked / 2 confirmed
+    int wm = dxccStatusMode(dxccEntity, _mode, _logNumber); //-1 error / 0 Not worked / 1 worked / 2 confirmed
+
+    if (wm==-1)
+    {
+        checkingMode = false;
     }
 
+    //qDebug() << "Awards::getDXStatus: wb=" << QString::number(wb) << " - wm=" << QString::number(wm) << endl;
+
     switch(dxccStatus(dxccEntity, _logNumber))
-    { //-1 error / 0 Not worked / 1 worked / 2 confirmed
-        case 0: // Not worked in any band                       => NEW ONE!
-            return 0;
+    {
+    case 0:
+        //qDebug() << "Awards::getDXStatus: return 0" << endl;
+        return 0;                   // ATNO
         break;
-        case 1: // Worked in another band, but not confirmed    => Could be new one, but it has been worked
-            switch (dxccStatusBandMode (dxccEntity, _band, _mode, _logNumber, checkingMode))
-            {// Status in this band & Mode? //-1 error / 0 Not worked / 1 worked / 2 confirmed
-                case 0: //
+    case 1:                         // Worked, not confirmed
+        switch (wb)
+        {
+        case 0:                     //  Not worked in this band but in another band
+            if (checkingMode)
+            {
+                if (wm==1)
+                {
+                    //qDebug() << "Awards::getDXStatus: return 4" << endl;
+                    return 4;
+                }
+                else
+                {
+                    //qDebug() << "Awards::getDXStatus: return 1" << endl;
                     return 1;
-                break;
-                case 1: //
-                    return 2;
-                break;
-                default:
-                    return -1;
-                break;
+                }
             }
-        break;
-        case 2: // Confirmed
-            switch (dxccStatusBandMode (dxccEntity, _band, _mode, _logNumber, checkingMode))
-            {// Status in this band & Mode? //-1 error / 0 Not worked / 1 worked / 2 confirmed
-                case 0: // Not worked in this band&Mode
-                    return 1;
-                break;
-                case 1: // Worked in this band&Mode
-                    return 2;
-                break;
-                case 2: // Confirmed in this band&Mode
+            else
+            {
+                //qDebug() << "Awards::getDXStatus: return 4 nc" << endl;
+                return 4;
+            }
+            break;
+        case 1:                     // Worked in this band
+            if (checkingMode)
+            {
+                if (wm==1)
+                {
+                    //qDebug() << "Awards::getDXStatus: return 3" << endl;
                     return 3;
-                break;
-                default:
-                    return -1;
-                break;
+                }
+                else
+                {
+                    //qDebug() << "Awards::getDXStatus: return 2" << endl;
+                    return 2;
+                }
             }
-        break;
-        default:
+            else
+            {
+                //qDebug() << "Awards::getDXStatus: return 3 nc" << endl;
+                return 3;
+            }
+
+            break;
+        default:                    // ERROR
+            //qDebug() << "Awards::getDXStatus: return -1 - 1" << endl;
             return -1;
-        break;
-    }
+            break;
+        }
+
+    break;
+    case 2:         // Confirmed
+        if (wb==2)
+        {
+            if (checkingMode)
+            {
+                if (wm==2)
+                {
+                    //qDebug() << "Awards::getDXStatus: return 13" << endl;
+                    return 13;
+                }
+                else if (wm==1)
+                {
+                    //qDebug() << "Awards::getDXStatus: return 12" << endl;
+                    return 12;
+                }
+                else
+                {
+                    //qDebug() << "Awards::getDXStatus: return 11" << endl;
+                    return 11;
+                }
+            }
+            else
+            {
+                //qDebug() << "Awards::getDXStatus: return 13 nc" << endl;
+                return 13;
+            }
+
+        }
+        else if ((wb ==1) || (wb == 0))
+        {
+            if (checkingMode)
+            {
+                if (wb==1)
+                {
+                    if (wm==1)
+                    {
+                        //qDebug() << "Awards::getDXStatus: return 8" << endl;
+                        return 8;
+                    }
+                    else
+                    {
+                        //qDebug() << "Awards::getDXStatus: return 6" << endl;
+                        return 6;
+                    }
+                }
+                else
+                {
+                    if (wm==1)
+                    {
+                        //qDebug() << "Awards::getDXStatus: return 7" << endl;
+                        return 7;
+                    }
+                    else
+                    {
+                        //qDebug() << "Awards::getDXStatus: return 5" << endl;
+                        return 5;
+                    }
+                }
+
+            }
+            else
+            {
+                if (wb==0)
+                {
+                    //qDebug() << "Awards::getDXStatus: return 7 nc" << endl;
+                    return 7;
+                }
+                else
+                {
+                    //qDebug() << "Awards::getDXStatus: return 8 nc" << endl;
+                    return 8;
+                }
+            }
+        }
+        else
+        {
+            //qDebug() << "Awards::getDXStatus: return -1 - 2" << endl;
+            return -1;
+        }
+    break;
+    default:
+        //qDebug() << "Awards::getDXStatus: return -1 default" << endl;
+        return -1;
+    break;
+
+    }   // END OF SWITCH
+
     return -1;
+
 }
+
+
 int Awards::dxccStatusBandMode(const int _ent, const int _band, const int _mode, const int _logNumber, bool _checkingMode)
 {//-1 error / 0 Not worked / 1 worked / 2 confirmed
-    //qDebug() << "Awards::dxccStatusBandMode: " << QString::number(_ent) << "/" << QString::number(_band) << "/" << QString::number(_mode) << endl;
+   //qDebug() << "Awards::dxccStatusBandMode: " << QString::number(_ent) << "/" << QString::number(_band) << "/" << QString::number(_mode) << endl;
     QSqlQuery query = QSqlQuery();
     QString queryString = QString();
 
     if (_checkingMode)
     {
+       //qDebug() << "Awards::dxccStatusBandMode: Checking Mode TRUE" << endl;
         queryString = QString("SELECT confirmed FROM awarddxcc WHERE dxcc='%1' AND band='%2' AND mode='%3' AND lognumber='%4' ").arg(QString::number(_ent)).arg(QString::number(_band)).arg(QString::number(_mode)).arg(QString::number(_logNumber));
     }
     else
     {
+       //qDebug() << "Awards::dxccStatusBandMode: Checking Mode FALSE" << endl;
         queryString = QString("SELECT confirmed FROM awarddxcc WHERE dxcc='%1' AND band='%2' AND lognumber='%3' ").arg(QString::number(_ent)).arg(QString::number(_band)).arg(QString::number(_logNumber));
     }
 
@@ -394,24 +537,29 @@ int Awards::dxccStatusBandMode(const int _ent, const int _band, const int _mode,
             {
                 if(query.value(0).toInt() == 1)
                 {
+                   //qDebug() << "Awards::dxccStatusBandMode: return - 2" << endl;
                     return 2;
                 }
                 else if(query.value(0).toInt() == 0)
                 {
+                   //qDebug() << "Awards::dxccStatusBandMode: return - 1" << endl;
                     return 1;
                 }
                 else
                 {
+                   //qDebug() << "Awards::dxccStatusBandMode: return - 0-1" << endl;
                     return 0;
                 }
             }
             else
             {
+               //qDebug() << "Awards::dxccStatusBandMode: return - 0-2" << endl;
                 return 0;
             }
         }
         else
         { // No value => Not Worked
+           //qDebug() << "Awards::dxccStatusBandMode: return - 0-3" << endl;
             return 0;
         }
 
@@ -419,16 +567,17 @@ int Awards::dxccStatusBandMode(const int _ent, const int _band, const int _mode,
     else
     { // The query fails...
       //TODO: Manage the query error
+       //qDebug() << "Awards::dxccStatusBandMode: return - -1" << endl;
         return -1;
     }
-
+    //qDebug() << "Awards::dxccStatusBandMode: return - 0-4" << endl;
     return 0;
 }
 
 
 int Awards::dxccStatus(const int _ent, const int _logNumber)
 {//-1 error / 0 Not worked / 1 worked / 2 confirmed
-    //qDebug() << "Awards::dxccStatus: " << QString::number(_ent) << endl;
+   //qDebug() << "Awards::dxccStatus: " << QString::number(_ent) << endl;
     QSqlQuery query = QSqlQuery();
     QString queryString = QString();
     int worked = 0;
@@ -446,30 +595,36 @@ int Awards::dxccStatus(const int _ent, const int _logNumber)
                     return 2;
                 }
                 else if(query.value(0).toInt() == 0)
-                {
+                {                 
                     worked = 1;
                 }
             }
         }
+       //qDebug() << "Awards::dxccStatus: return "<< QString::number(worked)  << endl;
         return worked;
 
     }
     else
     { // The query fails...
       //TODO: Manage the query error
+       //qDebug() << "Awards::dxccStatus: return -1"  << endl;
         return -1;
     }
+   //qDebug() << "Awards::dxccStatus: return 0"  << endl;
     return 0;
 }
 
 QColor Awards::getQRZDXStatusColor(const QStringList _qs)
 {
+    //qs << dxCall << spotBand << "-1" << QString::number(currentLog) ;
+
+
     //qDebug() << "Awards::getQRZDXStatusColor qs.length: " << QString::number(_qs.length()) << endl;
 
     //From Search QSO to QSL: q << _call << bandid << _mode << QString::number(currentLog);
 
 
-    //qDebug() << "Awards::getQRZDXStatusColor: " << _qs.at(0) << "/" << _qs.at(1) << "/" << _qs.at(2) << _qs.at(3) << endl;
+   //qDebug() << "Awards::getQRZDXStatusColor: " << _qs.at(0) << "/" << _qs.at(1) << "/" << _qs.at(2) << _qs.at(3) << endl;
     // Receives:  QStringList _qs;
     //_qs << QRZ << BandID << ModeId << lognumber;
 
@@ -481,37 +636,125 @@ QColor Awards::getQRZDXStatusColor(const QStringList _qs)
     */
 
     QColor returnedColor;
+
     int status = getDXStatus(_qs);
+
+   //qDebug() << "Awards::getQRZDXStatusColor: status: " << QString::number(status) << "/" << getDXStatusString(status) << endl;
+
     //qDebug() << "Awards::getQRZDXStatusColor: status: " << QString::number(status) << endl;
     switch (status) {
-
         case 0:
             returnedColor = newOneColor;
-           //qDebug() << "Awards::getQRZDXStatusColor: 0: " << returnedColor.name() << endl;
-
         break;
         case 1:
             returnedColor =  neededColor;
-           //qDebug() << "Awards::getQRZDXStatusColor: 1: " << returnedColor.name() << endl;
         break;
         case 2:
-            returnedColor =  workedColor;
-            //qDebug() << "Awards::getQRZDXStatusColor: 2: " << returnedColor.name() << endl;
+            returnedColor =  neededColor;
         break;
         case 3:
+            returnedColor =  workedColor;
+        break;
+        case 4:
+            returnedColor =  neededColor;
+        break;
+        case 5:
+            returnedColor =  neededColor;
+        break;
+        case 6:
+            returnedColor =  neededColor;
+        break;
+        case 7:
+            returnedColor =  neededColor;
+        break;
+        case 8:
+            returnedColor =  workedColor;
+        break;
+        case 9:
+            returnedColor =  neededColor;
+        break;
+        case 10:
+            returnedColor =  workedColor;
+        break;
+        case 11:
+            returnedColor =  neededColor;
+        break;
+        case 12:
+            returnedColor =  workedColor;
+        break;
+        case 13:
             returnedColor =  confirmedColor;
-            //qDebug() << "Awards::getQRZDXStatusColor: 3: " << returnedColor.name() << endl;
+        break;
         break;
         default:
             returnedColor =  defaultColor;
-           //qDebug() << "Awards::getQRZDXStatusColor: Def: " << returnedColor.name() << endl;
         break;
 
     }
     return returnedColor;
 }
 
+QString Awards::getDXStatusString (const int _status)
+{
 
+    //qDebug() << "Awards::getDXStatusString: " << QString::number(_status) << endl;
+
+QString message = QString();
+
+switch (_status) {
+
+    case 0:
+        message = QObject::tr("New One, work it!");
+        //message = QObject::tr("0-new One");
+    break;
+    case 1:
+        message = QObject::tr("Needed, work it!");
+        //message = QObject::tr("1-Needed, work it!");
+    break;
+    case 2:
+        message = QObject::tr("Needed, work it!");
+    break;
+    case 3:
+        message = QObject::tr("Worked but not confirmed");
+    break;
+    case 4:
+        message = QObject::tr("Needed, work it!");
+   break;
+    case 5:
+        message = QObject::tr("Needed, work it!");
+   break;
+    case 6:
+        message = QObject::tr("Needed, work it!");
+   break;
+    case 7:
+        message = QObject::tr("Needed, work it!");
+   break;
+    case 8:
+        message = QObject::tr("Worked but not confirmed");
+   break;
+    case 9:
+    message = QObject::tr("Needed, work it!");
+   break;
+    case 10:
+        message = QObject::tr("Worked but not confirmed");
+   break;
+    case 11:
+    message = QObject::tr("Needed, work it!");
+   break;
+    case 12:
+        message = QObject::tr("Worked but not confirmed");
+   break;
+    case 13:
+    message = QObject::tr("Confirmed");
+   break;
+    break;
+    default:
+        message = QObject::tr("Not identified");
+    break;
+
+}
+return message;
+}
 
 
 QString Awards::checkIfValidIOTA(const QString _tiota)
@@ -670,9 +913,11 @@ void Awards::recalculateAwards()
     bool DXCCknown = false;
     bool DXCCknownBefore = false;
     bool queryOk = false;
-    bool queryOkcq = false;
+    //bool queryOkcq = false;
     int errorCode = -1;
-    int nameCol, _id, _dxcc, _band, _mode, _cqz, _logNumber, _confirmed;
+    int nameCol, _id;
+    int _dxcc, _band, _mode, _cqz, _logNumber;
+    int _confirmed;
 
 
     int i = 0;
@@ -683,7 +928,7 @@ void Awards::recalculateAwards()
         query.next();
         numberOfQsos = query.value(0).toInt();
         //qDebug() << "Awards::recalculateAwards: MAX = " << QString::number(numberOfQsos) << endl;
-        step = getProgresStepForDialog(numberOfQsos);
+        step = util->getProgresStepForDialog(numberOfQsos);
 
     }
     else
@@ -817,7 +1062,7 @@ void Awards::recalculateAwards()
                 awardsQList << QString::number(_id);
                 awardsQList << QString::number(_logNumber);
             }
-// awardsQList << _dxcc / _cqz / _band / _mode / confirmed / id / logNumber
+    // awardsQList << _dxcc / _cqz / _band / _mode / confirmed / id / logNumber
             if ((DXCCknown) && (!DXCCknownBefore))
             { //I should update the DXCC in the log as it was not known before and now it is!
                 errorCode = setDXCCToQSO(_dxcc, _id);
@@ -1305,7 +1550,7 @@ bool Awards::setAwardWAZ(const int _cqz, const int _band, const int _mode, const
 }
 
 
-
+/*
 int Awards::getProgresStepForDialog(int totalSteps){
   //qDebug() << "FileManager::getProgresStepForDialog";
     if (totalSteps <=100)
@@ -1323,7 +1568,7 @@ int Awards::getProgresStepForDialog(int totalSteps){
     else
         return 50;
 }
-
+*/
 
 int Awards::setAwardDXCCst(const int _dxcc, const int _band, const int _mode, const bool _confirmed, const int _logNumber, const int _qsoId)
 {
@@ -1643,3 +1888,113 @@ int Awards::getDXMarathonScore(const int _year, const int _logNumber)
     return dxMarathon->getDXMarathonScore(_year, _logNumber);
 
 }
+
+bool Awards::isDXMarathonNeed(const int _dxcc, const int _cq, const int _year, const int _logNumber)
+{
+    return dxMarathon->neededForDXMarathon(_dxcc, _cq, _year, _logNumber);
+}
+
+int Awards::dxccStatusBand(const int _ent, const int _band, const int _logNumber) //-1 error / 0 Not worked / 1 worked / 2 confirmed
+{
+    //-1 error / 0 Not worked / 1 worked / 2 confirmed
+       //qDebug() << "Awards::dxccStatusBand: " << QString::number(_ent) << "/" << QString::number(_band) << endl;
+
+        QSqlQuery query = QSqlQuery();
+        QString queryString = QString();
+
+        queryString = QString("SELECT confirmed FROM awarddxcc WHERE dxcc='%1' AND band='%2' AND lognumber='%4' ").arg(QString::number(_ent)).arg(QString::number(_band)).arg(QString::number(_logNumber));
+
+
+        if (query.exec(queryString))
+        {
+            if (query.next())
+            {
+                if ( query.isValid() )
+                {
+                    if(query.value(0).toInt() == 1)         // Confirmed
+                    {
+
+                        return 2;
+                    }
+                    else if(query.value(0).toInt() == 0)    // Worked
+                    {
+                        return 1;
+                    }
+                    else                                    // Not worked
+                    {
+                        return 0;
+                    }
+                }                                           // Not present => Not worked
+                else
+                {
+                    return 0;
+                }
+            }
+            else                                            // Not present => Not worked
+            { // No value => Not Worked
+                return 0;
+            }
+
+        }
+        else
+        { // The query fails...
+          //TODO: Manage the query error
+            return -1;
+        }
+    //qDebug() << "Awards::dxccStatusBand: return - 0.3" << endl;
+        return 0;                                       // if arrives to here decision => not worked
+}
+
+int Awards::dxccStatusMode(const int _ent, const int _mode, const int _logNumber) //-1 error / 0 Not worked / 1 worked / 2 confirmed
+{
+    //-1 error / 0 Not worked / 1 worked / 2 confirmed
+      //qDebug() << "Awards::dxccStatusMode: " << QString::number(_ent) << "/" << QString::number(_mode) << endl;
+
+        QSqlQuery query = QSqlQuery();
+        QString queryString = QString();
+        if (_mode == -1)
+        {
+            return -1;
+        }
+
+        queryString = QString("SELECT confirmed FROM awarddxcc WHERE dxcc='%1' AND mode='%2' AND lognumber='%4' ").arg(QString::number(_ent)).arg(QString::number(_mode)).arg(QString::number(_logNumber));
+
+
+        if (query.exec(queryString))
+        {
+            if (query.next())
+            {
+                if ( query.isValid() )
+                {
+                    if(query.value(0).toInt() == 1)         // Confirmed
+                    {
+                        return 2;
+                    }
+                    else if(query.value(0).toInt() == 0)    // Worked
+                    {
+                        return 1;
+                    }
+                    else                                    // Not worked
+                    {
+                        return 0;
+                    }
+                }                                           // Not present => Not worked
+                else
+                {
+                    return 0;
+                }
+            }
+            else                                            // Not present => Not worked
+            { // No value => Not Worked
+                return 0;
+            }
+
+        }
+        else
+        { // The query fails...
+          //TODO: Manage the query error
+            return -1;
+        }
+        return 0;                                       // if arrives to here decision => not worked
+}
+
