@@ -41,6 +41,7 @@
 #include "awarddxmarathon.h"
 #include "dataproxy.h"
 #include "dataproxy_sqlite.h"
+#include "utilities.h"
 
 class QProgressDialog;
 
@@ -70,6 +71,7 @@ public:
     int getQSOsInLog(const int _logNumber);
 
     bool getIsDXCCConfirmed(const int _dxcc, const int _logNumber);
+    bool isThisSpotConfirmed(const QStringList _qs);
 
     QString checkIfValidIOTA(const QString _tiota);
 
@@ -83,6 +85,7 @@ public:
     int getDXMarathonDXCC(const int _year, const int _logNumber);
     int getDXMarathonCQ(const int _year, const int _logNumber);
     int getDXMarathonScore(const int _year, const int _logNumber);
+    bool isDXMarathonNeed(const int _dxcc, const int _cq, const int _year, const int _logNumber);
 
     // Receives:  QStringList _qs;
     //_qs << QRZ << BandId << lognumber;
@@ -115,6 +118,12 @@ private:
     _cConfirmed = 1     Set as Confirmed
     */
 
+
+    /**/
+    int dxccStatusBand(const int _ent, const int band, const int _logNumber); //-1 error / 0 Not worked / 1 worked / 2 confirmed
+    int dxccStatusMode(const int _ent, const int band, const int _logNumber); //-1 error / 0 Not worked / 1 worked / 2 confirmed
+    /**/
+
     void setAwardWAZ(const int _qsoId);
     bool setAwardWAZ(const int _cqz, const int _band, const int _mode, const int _workedOrConfirmed, const int _logNumber, const int _qsoId);
     int setAwardWAZst(const int _cqz, const int _band, const int _mode, const bool _confirmed, const int _logNumber, const int _qsoId);
@@ -122,7 +131,7 @@ private:
     _confirmed = 0     Set as Worked
     _confirmed = 1     Set as Confirmed
     */
-    int getProgresStepForDialog(int totalSteps);
+    //int getProgresStepForDialog(int totalSteps);
 
     QColor newOneColor;     //
     QColor neededColor;     //
@@ -133,6 +142,7 @@ private:
     World *world;
     DataProxy *dataProxy;
     DXMarathon *dxMarathon;
+    Utilities *util;
 
 
     typedef QMultiHash<int, int> DXStatus;
