@@ -44,6 +44,7 @@
 #include "database.h"
 #include "dataproxy.h"
 #include "dataproxy_sqlite.h"
+#include "utilities.h"
 
 enum
 {
@@ -54,6 +55,7 @@ enum
 
 class FileManager : public QWidget
 {
+    Q_OBJECT
 public:
     FileManager();
     FileManager(const QString _kontestDir);
@@ -65,19 +67,22 @@ public:
     bool adifLogExportMarked(const QString& _fileName);
     bool adifReqQSLExport(const QString& _fileName);
     bool cabrilloLogExport(const QString& _fileName, const int _contestType, const int logNconst);
+    bool modifySetupFile(const QString& _filename, QString _field, const QString _value);
+
 
 private:
     bool adifLogExportToFile(const QString& _fileName, const int _logN, bool justMarked = false, bool _qslRequested = false);
     bool cabrilloLogExportToFile(const QString& _fileName, const int logNconst);
     bool cabrilloLogExportCQWWToFile(const QString& _fileName, const int logNconst);
-    bool adifCheckMoreThanOneLog(QFile &_f);
+    //bool adifCheckMoreThanOneLog(QFile &_f);
+    int howManyLogsInFile(QFile & _f);
+    bool fillHashLog(QFile & _f);
+    QStringList getListOfLogsInFile(QFile & _f);
 
 
-    QString checkAndFixASCIIinADIF(const QString _data);
+    //QString checkAndFixASCIIinADIF(const QString _data);
 
-    bool processQsoReadingADIF(const QStringList _line, const int logNumber, const int _maxLog, QHash <int, int> &_logs);
-
-    int getProgresStepForDialog(int totalSteps);
+    bool processQsoReadingADIF(const QStringList _line, const int logNumber, const bool _keepLogsInFile, QHash <int, int> &_logs);
     void queryPreparation(const int _logN);
 
     bool checkADIFValidFormat(const QStringList _qs);
@@ -85,6 +90,9 @@ private:
     DataBase *db;
     //float softwareVersion;
     DataProxy *dataProxy;
+    Utilities *util;
+
+    bool rstTXDefault, rstRXDefault; // If true and a log is not including RST, 59 is automatically added
 
 
 
@@ -94,11 +102,13 @@ private:
     QString kontestVersion;
     //QProgressBar *progressBar;
     bool ignoreUnknownAlways;   // When importing ADIF, ignore all unknown fields.
+    bool noMoreQso;
 
     World *world;
     Awards *awards;
 
     QSqlQuery preparedQuery;
+    QHash<int, int> hashLogs;  // to create different logs when importing a ADIF file
 
 };
 #endif // FILEMANAGER_H
