@@ -15,11 +15,11 @@
  *                                                                           *
  *****************************************************************************/
 
-#include <QtGui>
+#include <QtWidgets>
 #include <QtSql>
 #include <QTranslator>
 #include <cstdlib>
-//#include <QDebug>
+#include <QDebug>
 
 #include "startwizard.h"
 #include "mainwindow.h"
@@ -27,18 +27,51 @@
 
 int main(int argc, char *argv[])
 {
-    QString version = "0.9.1.1";
+    QString version = "0.9.2.2";
     QDir d1 = QDir();
 
     QApplication app(argc, argv);
-// Translations begin
-    QTranslator qtTranslator;
-    qtTranslator.load("qt_" + QLocale::system().name(),
-            QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-    app.installTranslator(&qtTranslator);
 
-    QTranslator myappTranslator;
-    myappTranslator.load("klog_" + QLocale::system().name());
+    //QApplication app(argc, argv);
+    app.setApplicationName(QString("KLog"));
+    app.setApplicationVersion(QString(version));
+
+    // Translations begin
+        QTranslator qtTranslator;
+        qtTranslator.load("qt_" + QLocale::system().name(),
+                QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+        app.installTranslator(&qtTranslator);
+        QTranslator myappTranslator;
+
+#if defined(Q_OS_WIN)
+        myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()));
+       // qDebug() << "KLog WIN " << endl;
+       // qDebug() << "KLog: " << QLocale::system().name() << endl;
+        //qDebug() << "KLog trans: " <<  QLibraryInfo::location(QLibraryInfo::TranslationsPath) << endl;
+        //qDebug() << "KLog currentPath: " <<  QDir::currentPath() << endl;
+#elif defined(Q_OS_OSX)
+        myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()));
+        //myappTranslator.load("translations/klog_" + (QLocale::system().name()));
+        //qDebug() << "KLog OSX " << endl;
+        //qDebug() << "KLog: " << QLocale::system().name() << endl;
+        //qDebug() << "KLog trans: " <<  QLibraryInfo::location(QLibraryInfo::TranslationsPath) << endl;
+        //qDebug() << "KLog currentPath: " <<  QDir::currentPath() << endl;
+
+#else
+        myappTranslator.load("klog_" + (QLocale::system().name()));
+        //qDebug() << "KLog OTHER OS " << endl;
+#endif
+
+
+
+
+
+    //myappTranslator.load("klog_" + (QLocale::system().name()).left(2));
+    //qDebug() << "KLog locale: " << QLocale::system().name() << endl;
+    //qDebug() << "KLog locale2: " << (QLocale().name()).left(2) << endl;
+    //qDebug() << "KLog language: " << QLocale::system().language() << endl;
+    //qDebug() << "KLog AppPath: " << QCoreApplication::applicationDirPath() << endl;
+
     app.installTranslator(&myappTranslator);
 // Translations end
 
@@ -89,27 +122,27 @@ int main(int argc, char *argv[])
     {
         //qDebug() << "MAIN:  Starting wizard... " << endl;
 
-        StartWizard *wizard = new StartWizard(kontestDir, version);
+        StartWizard *wizard = new StartWizard(kontestDir, version);        
         wizard->setModal(true);
         inMemory = wizard->exec();
 
         if (inMemory == 1)
         {
-           //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << endl;
+          //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << endl;
             MainWindow mw(kontestDir, version);
             mw.show();
             return app.exec();
         }
         else if (inMemory == 2)
         {
-            //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in file " << endl;
+           //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in file " << endl;
             MainWindow mw(kontestDir, version);
             mw.show();
             return app.exec();
         }
         else
         {
-            //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << endl;
+           //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << endl;
 
             QMessageBox msgBox;
             msgBox.setText("Install wizard was cancelled before completing...");
