@@ -26,14 +26,13 @@
  *                                                                           *
  *****************************************************************************/
 
-#include <QtGui>
-//#include <QtWidgets>
+#include <QtWidgets>
 #include <QPrinter>
 #include <QPrintDialog>
 
 #include <QNetworkRequest>
 #include <QNetworkReply>
-
+#include <QtAlgorithms>
 
 #include "database.h"
 #include "setupdialog.h"
@@ -49,6 +48,9 @@
 #include "dxcluster.h"
 #include "awards.h"
 #include "mainwindowsattab.h"
+#include "elogclublog.h"
+#include "utilities.h"
+#include "downloadcty.h"
 
 class QTimer;
 class QDateTime;
@@ -170,15 +172,19 @@ private slots:
     void sloteQSLSentComboBoxChanged();
     void slotQSLViaTextChanged();
 
+    void slotSetPropMode(const QString _p);
+
     void slotUpdateCTYDAT();
+    void slotWorldReload();
     void slotToolSearchNeededQSLToSend();
     void slotToolSearchRequestedQSLToSend();
     void slotToolSearchNeededQSLPendingToReceive();
+    void slotToolSearchNeededQSLRequested();
     void slotToolSearchQSL(const int actionQSL);
 
     void slotExitFromSlotDialog(const int exitID);
 
-    void slotDownloadFinished(QNetworkReply *reply);
+    //void slotDownloadFinished(QNetworkReply *reply);
 
     void fillQSOData();
 
@@ -186,6 +192,8 @@ private slots:
     void openFile();
     bool saveFile(const QString _fileName);
     bool saveFileAs();
+    bool slotOpenKLogFolder();
+
 
 
     void slotFilePrint();
@@ -211,23 +219,34 @@ private slots:
     void slotAnalyzeDxClusterSignal(const QStringList _qs);
 
     // CLUSTER
+    //CLUBLOG
+    void slotElogClubLogShowMessage(const QString _s);
+    void slotElogClubLogProcessAnswer(const int _i, const int _qID);
+    void slotElogClubLogDisable(const bool _b);
+    //CLUBLOG
 
 
 private:
-    //UPDATE CTY.DAT
+    bool maybeSave();
 
+    //UPDATE CTY.DAT
+/*
     bool downloadCTYFile();
     bool downloadCtyDatFile();
     bool saveToDisk(const QString &filename, QIODevice *data);
-    bool maybeSave();
+
 
 
     QString saveFileName(const QUrl &url);
 
     QNetworkAccessManager manager;
     QNetworkRequest request;
+*/
+       // NEW
+    DownLoadCTY *downloadcty;
 
     //</UPDATE CTY.DAT>
+
     void createStatusBar();
     void createUI();
     void createUICQWW();
@@ -277,6 +296,7 @@ private:
     QString readDataFromUIDXModifying();
 
     int getDXCCFromComboBox();
+    QString getPropModeFromComboBox();
 
     //QString readDataFromUICQWW();
 
@@ -286,11 +306,12 @@ private:
     int checkIfWorkedB4(const QString _qrz);
     bool checkContest();    
     void showStatusOfDXCC(const QStringList _qs);
+    void showDXMarathonNeeded(const int _dxcc, const int _cqz, const int _year, const int _log);
 
     bool createConnection();
     void createData();
     bool processConfigLine(const QString _line);
-    void readConfigData();
+    void readConfigData();    
     void defineStationCallsign();
 
     void checkIfNewBandOrMode();
@@ -301,9 +322,10 @@ private:
     void qsoToEdit (const int _qso);
     void showInfoFromLocators(const QString _loc1, const QString _loc2);
     void clearInfoFromLocators();
+    void completeWithPreviousQSO(const QString _call);
 
     //void showQRZEntityInfo(const QString _qrz);
-    void showEntityInfo(const int _enti);
+    void showEntityInfo(const int _enti, int _cq=-1, int _itu=-1);
     QString getStyleColorToLabelFromBand(const QString _b, const QString _q);
     void showAwards();
     void showDXMarathon(const int _year);
@@ -329,6 +351,7 @@ private:
     FileManager *filemanager;
     Locator *locator;
     Awards *awards;
+    Utilities *util;
     //WorldEditorWidget *worldEditor;
 
     HelpHelpDialog *helpHelpDialog;
@@ -371,6 +394,9 @@ private:
     QMenu *setupMenu;
     QMenu *helpMenu;
 
+
+
+    QAction *klogFolderAct;
     QAction *openAct;
     QAction *saveAct;
     QAction *exitAct;
@@ -395,6 +421,7 @@ private:
     QAction *findQSO2QSLAct;
     QAction *findRequestedQSLAct;
     QAction *findQSLPendingToReceiveAct;
+    QAction *findQSLDXRequestedAct;
 
     QAction *downloadCTYAct;
 
@@ -428,10 +455,10 @@ private:
     QPushButton *OKButton, *spotItButton, *clearButton;
     QStringList bands;
     QStringList modes;
-    QStringList entitiesList;
+    QStringList entitiesList, propModeList;
 
     // UI DX
-    QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel;
+    QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel;
     QLabel *infoLabel1, *infoLabel2;
     QLabel *bandLabel1, *bandLabel2, *bandLabel3, *bandLabel4;
     QLabel *bandLabel5, *bandLabel6, *bandLabel7, *bandLabel8;
@@ -440,7 +467,7 @@ private:
     QLabel *gradShortLabel, *distShortLabel;
     QLabel *gradLongLabel, *distLongLabel;
 
-    QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox;
+    QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
     QComboBox *operatingYearsComboBox;
     QLineEdit *iotaNumberLineEdit, *operatorLineEdit, *stationCallSignLineEdit, *myLocatorLineEdit, *commentLineEdit;
     QTextEdit *notesTextEdit;
@@ -451,8 +478,8 @@ private:
                 *localConfirmedQLCDNumber, *localWorkedQLCDNumber,
                 *qsoConfirmedQLCDNumber, *qsoWorkedQLCDNumber,
                 *dxMarathonDXCCQLCDNumber, *dxMarathonCQQLCDNumber, *dxMarathonPointsQLCDNumber;
-    QComboBox *eqslSentComboBox, *eqslRecComboBox, *lotwSentComboBox, *lotwRecComboBox;
-    QDateEdit *eqslSentQDateEdit, *eqslRecQDateEdit, *lotwSentQDateEdit, *lotwRecQDateEdit;
+    QComboBox *eqslSentComboBox, *eqslRecComboBox, *lotwSentComboBox, *lotwRecComboBox, *clublogComboBox;
+    QDateEdit *eqslSentQDateEdit, *eqslRecQDateEdit, *lotwSentQDateEdit, *lotwRecQDateEdit, *clublogQDateEdit;
 
     QComboBox *qslSentComboBox, *qslRecComboBox, *qslSentViaComboBox, *qslRecViaComboBox;
     QDateEdit *qslSentQDateEdit, *qslRecQDateEdit;
@@ -495,12 +522,14 @@ private:
 
     QString stx;
     QString srx;
-
-    bool realTime, UTCTime, alwaysADIF, needToSave, useDefaultLogFileName, upAndRunning, qrzSmallModDontCalculate, imperialSystem, sendQSLWhenRec, keepMyData;
+    QPalette palRed, palBlack; // To paint Text in red or black(normal)
+    bool realTime, UTCTime, alwaysADIF, needToSave, useDefaultLogFileName, upAndRunning, qrzSmallModDontCalculate, imperialSystem, sendQSLWhenRec, keepMyData, completeWithPrevious, completedWithPreviousQTH, completedWithPreviousLocator, completedWithPreviousName, completedWithPreviousIOTA, completedWithPreviousQSLVia;
     bool cleaning;
+    bool manageMode; // If true, the DXCC and awards will take the mode into consideration to decide if needed or worked. False implies only band is taken into account
     // Station Setup
     bool configured, modify;
     bool needToEnd; // Just to control if the software needs to end.
+    bool qrzAutoChanging; //To stop executing the slotQRZTextChanged just because KLog uppercase a letter
     QString mainQRZ, stationQRZ, operatorQRZ, myLocator, dxLocator;
     QString lastOperatorQRZ, lastStationQRZ, lastMyLocator;
     double myPower, lastPower;
@@ -521,6 +550,16 @@ private:
     QColor confirmedColor;
     QColor newOneColor;
 
+    //<CLUBLOG>
+    bool clublogActive, clublogRealTime;
+    QString clublogUser, clublogPass, clublogEmail;
+
+    eLogClubLog *elogClublog;
+    int clublogAnswer;
+    QStringList clublogPrevQSO;
+
+    //</CLUBLOG>
+
     // Contest
     int contestMode, points, qsoPoints, multipliers, qsoMultiplier;
 
