@@ -34,47 +34,129 @@ This class calls all the othet "Setup..." to manage the configuration
 
 SetupDialog::SetupDialog(const bool _firstTime)
 {
-    //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+   //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+    util = new Utilities;
     nolog = true;
     configFileName = "klogrc";
     version = ".";
     pageRequested = 0;
+   //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     dataProxy = new DataProxy_SQLite();
+   //qDebug() << "SetupDialog::SetupDialog 3" << endl;
 
     firstTime = _firstTime;
     if (firstTime)
     {
-        //qDebug() << "SetupDialog::SetupDialog FIRST TIME = TRUE" << endl;
+       //qDebug() << "SetupDialog::SetupDialog FIRST TIME = TRUE" << endl;
     }
     else
     {
-        //qDebug() << "SetupDialog::SetupDialog FIRST TIME = FALSE" << endl;
+       //qDebug() << "SetupDialog::SetupDialog FIRST TIME = FALSE" << endl;
     }
+   //qDebug() << "SetupDialog::SetupDialog 3.1" << endl;
 
     logsPageTabN=-1;
+   //qDebug() << "SetupDialog::SetupDialog 3.2" << endl;
+    locator = new Locator();
+   //qDebug() << "SetupDialog::SetupDialog 3.3" << endl;
+    tabWidget = new QTabWidget;
+   //qDebug() << "SetupDialog::SetupDialog 3.4" << endl;
+
+
+    userDataPage = new SetupPageUserDataPage();
+   //qDebug() << "SetupDialog::SetupDialog 3.5" << endl;
+    bandsModesPage = new SetupPageBandsModes(this);
+   //qDebug() << "SetupDialog::SetupDialog 3.6" << endl;
+    dxClusterPage = new SetupPageDxCluster(this);
+   //qDebug() << "SetupDialog::SetupDialog 3.7" << endl;
+    colorsPage = new SetupPageColors(this);
+   //qDebug() << "SetupDialog::SetupDialog 3.8" << endl;
+    miscPage = new SetupPageMisc(this);
+   //qDebug() << "SetupDialog::SetupDialog 3.9" << endl;
+    worldEditorPage = new SetupPageWorldEditor (this);
+   //qDebug() << "SetupDialog::SetupDialog 3.10" << endl;
+    logsPage = new SetupPageLogs(this);
+   //qDebug() << "SetupDialog::SetupDialog 3.11" << endl;
+    clubLogPage = new SetupPageClubLog(this);
+   //qDebug() << "SetupDialog::SetupDialog 3.12" << endl;
+
+   //qDebug() << "SetupDialog::SetupDialog 4" << endl;
+
+    tabWidget->addTab(userDataPage, tr("My Data"));    
+    tabWidget->addTab(bandsModesPage, tr("Bands/Modes"));
+    tabWidget->addTab(dxClusterPage, tr("DX-Cluster"));
+    tabWidget->addTab(colorsPage, tr("Colors"));
+    tabWidget->addTab(miscPage, tr("Misc"));
+    tabWidget->addTab(worldEditorPage, tr("World Editor"));
+    logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
+    tabWidget->addTab(clubLogPage, tr("ClubLog"));
+
+    QPushButton *closeButton = new QPushButton(tr("Cancel"));
+    QPushButton *okButton = new QPushButton(tr("OK"));
+
+    connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
+    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
+
+    QHBoxLayout *horizontalLayout = new QHBoxLayout;
+    horizontalLayout->addWidget(tabWidget);
+
+    QHBoxLayout *buttonsLayout = new QHBoxLayout;
+    buttonsLayout->addStretch(1);
+    buttonsLayout->addWidget(okButton);
+    buttonsLayout->addWidget(closeButton);
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addLayout(horizontalLayout);
+    mainLayout->addLayout(buttonsLayout);
+
+    setLayout(mainLayout);
+
+    setWindowTitle(tr("Config Dialog"));
+    slotReadConfigData();
+
+
+    if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
+    {
+        tabWidget->setCurrentIndex(logsPageTabN);
+    }
+    nolog = !(haveAtleastOneLog());
+   //qDebug() << "SetupDialog::SetupDialog END" << endl;
+}
+
+
+
+SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
+{
+    //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+    util = new Utilities;
+    firstTime = _firstTime;
+    dataProxy = new DataProxy_SQLite();
+    configFileName = _configFile;
+    version = _softwareVersion;
+    pageRequested = _page;
+    int logsPageTabN=-1;
 
     locator = new Locator();
 
     tabWidget = new QTabWidget;
 
-
     userDataPage = new SetupPageUserDataPage();
     bandsModesPage = new SetupPageBandsModes(this);
     dxClusterPage = new SetupPageDxCluster(this);
     colorsPage = new SetupPageColors(this);
     miscPage = new SetupPageMisc(this);
     worldEditorPage = new SetupPageWorldEditor (this);
-
     logsPage = new SetupPageLogs(this);
+    clubLogPage = new SetupPageClubLog(this);
 
-    tabWidget->addTab(userDataPage, tr("My Data"));
+    tabWidget->addTab(userDataPage, tr("User data"));
     tabWidget->addTab(bandsModesPage, tr("Bands/Modes"));
-    tabWidget->addTab(dxClusterPage, tr("DX-Cluster"));
+    tabWidget->addTab(dxClusterPage, tr("D&X-Cluster"));
     tabWidget->addTab(colorsPage, tr("Colors"));
     tabWidget->addTab(miscPage, tr("Misc"));
-
     tabWidget->addTab(worldEditorPage, tr("World Editor"));
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
+    tabWidget->addTab(clubLogPage, tr("ClubLog"));
 
     QPushButton *closeButton = new QPushButton(tr("Cancel"));
     QPushButton *okButton = new QPushButton(tr("OK"));
@@ -107,71 +189,6 @@ SetupDialog::SetupDialog(const bool _firstTime)
     nolog = !(haveAtleastOneLog());
 }
 
-
-
-SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
-{
-    //qDebug() << "SetupDialog::SetupDialog 2" << endl;
-    firstTime = _firstTime;
-    dataProxy = new DataProxy_SQLite();
-    configFileName = _configFile;
-    version = _softwareVersion;
-    pageRequested = _page;
-    int logsPageTabN=-1;
-
-    locator = new Locator();
-
-    tabWidget = new QTabWidget;
-
-    userDataPage = new SetupPageUserDataPage();
-    bandsModesPage = new SetupPageBandsModes(this);
-    dxClusterPage = new SetupPageDxCluster(this);
-    colorsPage = new SetupPageColors(this);
-    miscPage = new SetupPageMisc(this);
-    worldEditorPage = new SetupPageWorldEditor (this);
-
-    logsPage = new SetupPageLogs(this);
-
-    tabWidget->addTab(userDataPage, tr("User data"));
-    tabWidget->addTab(bandsModesPage, tr("Bands/Modes"));
-    tabWidget->addTab(dxClusterPage, tr("DX-Cluster"));
-    tabWidget->addTab(colorsPage, tr("Colors"));
-    tabWidget->addTab(miscPage, tr("Misc"));
-
-    tabWidget->addTab(worldEditorPage, tr("World Editor"));
-    logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
-
-    QPushButton *closeButton = new QPushButton(tr("Cancel"));
-    QPushButton *okButton = new QPushButton(tr("OK"));
-
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
-    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
-
-    QHBoxLayout *horizontalLayout = new QHBoxLayout;
-    horizontalLayout->addWidget(tabWidget);
-
-    QHBoxLayout *buttonsLayout = new QHBoxLayout;
-    buttonsLayout->addStretch(1);
-    buttonsLayout->addWidget(okButton);
-    buttonsLayout->addWidget(closeButton);
-
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    mainLayout->addLayout(horizontalLayout);
-    mainLayout->addLayout(buttonsLayout);
-
-    setLayout(mainLayout);
-
-    setWindowTitle(tr("Config Dialog"));
-
-    slotReadConfigData();
-
-    if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
-    {
-        tabWidget->setCurrentIndex(logsPageTabN);
-    }
-
-}
-
 SetupDialog::~SetupDialog()
 {
     //qDebug() << "SetupDialog::~SetupDialog " << endl;
@@ -179,20 +196,22 @@ SetupDialog::~SetupDialog()
 
 void SetupDialog::setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-   //qDebug() << "SetupDialog::setData: " << QString::number(_page) << endl;
+  //qDebug() << "SetupDialog::setData: " << QString::number(_page) << endl;
+    nolog = !(haveAtleastOneLog());
     firstTime = _firstTime;
     if (firstTime)
     {
-        //qDebug() << "SetupDialog::setData FIRST TIME! " << endl;
+       //qDebug() << "SetupDialog::setData FIRST TIME! " << endl;
     }
     else
     {
-        //qDebug() << "SetupDialog::setData NOT FIRST TIME! " << endl;
+       //qDebug() << "SetupDialog::setData NOT FIRST TIME! " << endl;
     }
 
     setConfigFile(_configFile);
     setSoftVersion(_softwareVersion);
     setPage(_page);
+    //removeBandModeDuplicates();
 
 }
 
@@ -426,7 +445,7 @@ void SetupDialog::slotOkButtonClicked()
         stream << "Bands=" << bandsModesPage->getBands() << ";" <<  endl;
         stream << "Modes=" << bandsModesPage->getModes() << ";" <<  endl;
 
-        stream << "InMemory=" << miscPage->getInMemory() << ";" <<  endl;
+        //stream << "InMemory=" << miscPage->getInMemory() << ";" <<  endl;
         stream << "RealTime=" << miscPage->getRealTime() << ";" <<  endl;
         stream << "UTCTime=" << miscPage->getUTCTime() << ";" <<  endl;
         stream << "AlwaysADIF=" << miscPage->getAlwaysADIF() << ";" <<  endl;
@@ -436,7 +455,7 @@ void SetupDialog::slotOkButtonClicked()
         stream << "SendQSLWhenRec=" << miscPage->getSendQSLWhenRec() << ";" <<  endl;
         stream << "ShowCallsignInSearch=" << miscPage->getShowStationCallSignInSearch() << ";" <<  endl;
         stream << "KeepMyData=" << miscPage->getKeepMyData() << ";" <<  endl;
-
+        stream << "CompleteWithPrevious=" << miscPage->getCompleteWithPrevious() << ";" <<  endl;
 
 
         if ((!(dxClusterPage->getSelectedDxClusterServer()).isNull()) && (  (dxClusterPage->getSelectedDxClusterServer()).length() > 0   ))
@@ -448,9 +467,9 @@ void SetupDialog::slotOkButtonClicked()
         stringList.clear();
         stringList << dxClusterPage->getDxclusterServersComboBox();
 
-        if (stringList.count()>0)
+        if (stringList.size()>0)
         { 
-            for (int i = 0; i < stringList.count(); i++)
+            for (int i = 0; i < stringList.size(); i++)
             {
                  stream << "DXClusterServerPort="<< stringList.at(i) << ";" << endl;
             }
@@ -472,6 +491,19 @@ void SetupDialog::slotOkButtonClicked()
         stream << "DefaultColor=" << colorsPage->getDefaultColor() << ";" <<  endl;
         stream << "SelectedLog=" << QString::number(logsPage->getSelectedLog()) << ";" <<  endl;
 
+        // CLUBLOG
+
+        if ((clubLogPage->getClubLog()).toUpper() == "TRUE" )
+        {
+            stream << "ClubLogActive=" << clubLogPage->getClubLog() << ";" <<  endl;
+            stream << "ClubLogRealTime=" << clubLogPage->getClubLogRealTime() << ";" <<  endl;
+            stream << "ClubLogCall=" << clubLogPage->getCallsign() << ";" <<  endl;
+            stream << "ClubLogPass=" << clubLogPage->getPassword() << ";" <<  endl;
+            stream << "ClubLogEmail=" << clubLogPage->getEmail() << ";" <<  endl;
+            stream << "ClubLogUseStationCallsign=" << clubLogPage->getUseQSOStationCallsign() << ";" << endl;
+        }
+
+        // CLUBLOG
 
         file.close ();
     }
@@ -482,18 +514,27 @@ void SetupDialog::slotOkButtonClicked()
 
 void SetupDialog::slotReadConfigData()
 {
-    //qDebug() << "SetupDialog::slotReadConfigData" << endl;
+  //qDebug() << "SetupDialog::slotReadConfigData" << endl;
+    if (firstTime)
+    {
+        setDefaults();
+        bands.removeDuplicates();
+        modes.removeDuplicates();
+        bandsModesPage->setActiveModes(modes);
+        bandsModesPage->setActiveBands(bands);
+    }
+
 
     QFile file(configFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
-        //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
+       //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
         //firstTime = true;
         return;
     }
 
     //dxClusterServers.clear();
 
-    setDefaults();
+
 
     while (!file.atEnd()) {
         QByteArray line = file.readLine();
@@ -503,6 +544,23 @@ void SetupDialog::slotReadConfigData()
     dxClusterPage->setDxclusterServersComboBox(dxClusterServers);
     dxClusterPage->setSelectedDxClusterServer(dxClusterServerToUse);
 
+    if (modes.isEmpty())
+    {
+        modes << "SSB" << "CW" << "RTTY";
+
+    }
+    if (bands.isEmpty())
+    {
+        bands << "10M" << "12M" << "15M" << "17M" << "20M" << "40M" << "80M" << "160M";
+
+    }
+    int a = modes.removeDuplicates();
+    //qDebug() << "SetupDialog::slotReadConfigData - duplicate modes: " << QString::number(a)  << endl;
+    bandsModesPage->setActiveModes(modes);
+    a = bands.removeDuplicates();
+   //qDebug() << "SetupDialog::slotReadConfigData - duplicate bands: " << QString::number(a)  << endl;
+    bandsModesPage->setActiveBands(bands);
+
 }
 
 bool SetupDialog::processConfigLine(const QString _line)
@@ -510,11 +568,11 @@ bool SetupDialog::processConfigLine(const QString _line)
 
     //qDebug() << "SetupDialog::processConfigLine: " << _line << endl;
 
-    QString line = (_line.toUpper()).simplified();
+    QString line = _line.simplified();
     //line.simplified();
-
+    int i = 0; //aux variable
     QStringList values = line.split("=", QString::SkipEmptyParts);
-
+    QString tab = QString();
 
 
     if (line.startsWith('#')){
@@ -526,6 +584,8 @@ bool SetupDialog::processConfigLine(const QString _line)
         return false;
     }
     QString value = values.at(1);
+    tab = (values.at(0)).toUpper();
+
     int endValue = value.indexOf(';');
     if (endValue>-1){
 
@@ -533,160 +593,191 @@ bool SetupDialog::processConfigLine(const QString _line)
     }
     value = checkAndFixASCIIinADIF(value); // Check whether the value is valid.
 
-    if (values.at(0) == "CALLSIGN"){
+    if (tab == "CALLSIGN"){
         //qDebug() << "SetupDialog::processConfigLine: CALLSIGN: " << value << endl;
         userDataPage->setStationQrz(value);
-    }else if (values.at(0) == "OPERATORS"){
+    }else if (tab == "OPERATORS"){
         userDataPage->setOperators(value);
-    }else if (values.at(0)=="CQZ"){
+    }else if (tab=="CQZ"){
         userDataPage->setCQz((value).toInt());
 
-    }else if (values.at(0)=="ITUZ"){
+    }else if (tab=="ITUZ"){
         userDataPage->setITUz((value).toInt());
-    }else if (values.at(0)=="CONTEST"){
+    }else if (tab=="CONTEST"){
         //userDataPage->setContest(value);
-    }else if (values.at(0)=="MODES"){
+    }else if (tab=="MODES"){
         readActiveModes(value);
+        modes.removeDuplicates();
         bandsModesPage->setActiveModes(modes);
-    }else if (values.at(0)=="BANDS"){
+    }else if (tab=="BANDS"){
         readActiveBands(value);
+        bands.removeDuplicates();
         bandsModesPage->setActiveBands(bands);
-    }else if (values.at(0)=="INMEMORY"){
-        miscPage->setInMemory(value);
-    }else if (values.at(0)=="REALTIME"){
+    //}else if (tab=="INMEMORY"){
+    //    miscPage->setInMemory(value);
+    }else if (tab=="REALTIME"){
         miscPage->setRealTime(value);
-    }else if (values.at(0)=="UTCTIME"){
+    }else if (tab=="UTCTIME"){
         miscPage->setUTCTime(value);
-    }else if (values.at(0)=="ALWAYSADIF"){
+    }else if (tab=="ALWAYSADIF"){
         miscPage->setAlwaysADIF(value);
-    }else if (values.at(0)=="USEDEFAULTNAME"){
+    }else if (tab=="USEDEFAULTNAME"){
         miscPage->setDefaultFileName(value);
-    }else if (values.at(0)=="DEFAULTADIFFILE"){
+    }else if (tab=="DEFAULTADIFFILE"){
         miscPage->setDefaultFileName(value.toLower());
-    }else if (values.at(0)=="IMPERIALSYSTEM"){
+    }else if (tab=="IMPERIALSYSTEM"){
         miscPage->setImperial(value.toLower());
-    }else if (values.at(0)=="KEEPMYDATA"){
+    }else if (tab=="KEEPMYDATA"){
         miscPage->setKeepMyData(value.toLower());
-    }else if (values.at(0)=="SENDQSLWHENREC"){
+    }else if (tab=="COMPLETEWITHPREVIOUS"){
+        miscPage->setCompleteWithPrevious(value.toLower());
+    }else if (tab=="SENDQSLWHENREC"){
         miscPage->setSendQSLWhenRec(value.toLower());
     }
-    else if (values.at(0)=="SHOWCALLSIGNINSEARCH"){
+    else if (tab=="SHOWCALLSIGNINSEARCH"){
         miscPage->setShowStationCallSignInSearch(value.toLower());
     }
-    else if (values.at(0)=="NAME")
+    else if (tab =="NAME")
     {
         userDataPage->setName(value);
     }
-    else if (values.at(0)=="ADDRESS1")
+    else if (tab =="ADDRESS1")
     {
         userDataPage->setAddress1(value);
     }
-    else if (values.at(0)=="ADDRESS2")
+    else if (tab =="ADDRESS2")
     {
         userDataPage->setAddress2(value);
     }
-    else if (values.at(0)=="ADDRESS3")
+    else if (tab =="ADDRESS3")
     {
         userDataPage->setAddress3(value);
     }
-    else if (values.at(0)=="ADDRESS4")
+    else if (tab =="ADDRESS4")
     {
         userDataPage->setAddress4(value);
     }
-    else if (values.at(0)=="CITY")
+    else if (tab =="CITY")
     {
         userDataPage->setCity(value);
     }
-    else if (values.at(0)=="ZIPCODE")
+    else if (tab =="ZIPCODE")
     {
         userDataPage->setZipCode(value);
     }
-    else if (values.at(0)=="PROVINCESTATE")
+    else if (tab =="PROVINCESTATE")
     {
         userDataPage->setProvince(value);
     }
-    else if (values.at(0)=="COUNTRY")
+    else if (tab =="COUNTRY")
     {
         userDataPage->setCountry(value);
     }
-    else if (values.at(0)=="POWER")
+    else if (tab =="POWER")
     {
         userDataPage->setPower(value);
     }
-    else if (values.at(0)=="RIG1")
+    else if (tab =="RIG1")
     {
         userDataPage->setRig1(value);
     }
-    else if (values.at(0)=="RIG2")
+    else if (tab =="RIG2")
     {
         userDataPage->setRig2(value);
     }
-    else if (values.at(0)=="RIG3")
+    else if (tab =="RIG3")
     {
         userDataPage->setRig3(value);
     }
 
-    else if (values.at(0)=="ANTENNA1")
+    else if (tab =="ANTENNA1")
     {
         userDataPage->setAntenna1(value);
     }
-    else if (values.at(0)=="ANTENNA2")
+    else if (tab =="ANTENNA2")
     {
         userDataPage->setAntenna2(value);
     }
-    else if (values.at(0)=="ANTENNA3")
+    else if (tab =="ANTENNA3")
     {
         userDataPage->setAntenna3(value);
     }
-    else if (values.at(0)=="STATIONLOCATOR"){
+    else if (tab =="STATIONLOCATOR"){
 
         if ( locator->isValidLocator(value) )
         {
             userDataPage->setStationLocator(value);
         }
 
-    }else if (values.at(0)=="DXCLUSTERSHOWHF"){
+    }else if (tab =="DXCLUSTERSHOWHF"){
         dxClusterPage->setShowHFRadiobutton(value);
-    }else if (values.at(0)=="DXCLUSTERSHOWVHF"){
+    }else if (tab =="DXCLUSTERSHOWVHF"){
         dxClusterPage->setShowVHFRadiobutton(value);
-    }else if (values.at(0)=="DXCLUSTERSHOWWARC"){
+    }else if (tab =="DXCLUSTERSHOWWARC"){
         dxClusterPage->setShowWARCRadiobutton(value);
-    }else if (values.at(0)=="DXCLUSTERSHOWWORKED"){
+    }else if (tab =="DXCLUSTERSHOWWORKED"){
         dxClusterPage->setShowWorkedRadiobutton(value);
-    }else if (values.at(0)=="DXCLUSTERSHOWCONFIRMED"){
+    }else if (tab =="DXCLUSTERSHOWCONFIRMED"){
         dxClusterPage->setShowConfirmedRadiobutton(value);
-    }else if (values.at(0)=="DXCLUSTERSHOWANN"){
+    }else if (tab =="DXCLUSTERSHOWANN"){
         dxClusterPage->setShowANNRadiobutton(value);
-    }else if (values.at(0)=="DXCLUSTERSHOWWWV"){
+    }else if (tab =="DXCLUSTERSHOWWWV"){
         dxClusterPage->setShowWWVRadiobutton(value);
-    }else if (values.at(0)=="DXCLUSTERSHOWWCY"){
+    }else if (tab =="DXCLUSTERSHOWWCY"){
         dxClusterPage->setShowWCYRadiobutton(value);
-    }else if(values.at(0)=="DXCLUSTERSERVERPORT"){
+    }else if(tab =="DXCLUSTERSERVERPORT"){
         dxClusterServers << value;
         //qDebug() << "SetupDialog::processConfigLine: dxClusterServers: " << dxClusterServers.last() << endl;
 
-    }else if (values.at(0) =="DXCLUSTERSERVERTOUSE"){
+    }else if (tab  =="DXCLUSTERSERVERTOUSE"){
         dxClusterServerToUse=value;
     }
-    else if(values.at(0)=="NEWONECOLOR"){
+    else if(tab =="NEWONECOLOR"){
         colorsPage->setNewOneColor(value);
-    }else if(values.at(0)=="NEEDEDCOLOR"){
+    }else if(tab =="NEEDEDCOLOR"){
         colorsPage->setNeededColor(value);
-    }else if(values.at(0)=="WORKEDCOLOR"){
+    }else if(tab =="WORKEDCOLOR"){
         colorsPage->setWorkedColor(value);
-    }else if(values.at(0)=="CONFIRMEDCOLOR"){
+    }else if(tab =="CONFIRMEDCOLOR"){
         colorsPage->setConfirmedColor(value);
-    }else if(values.at(0)=="DEFAULTCOLOR"){
+    }else if(tab =="DEFAULTCOLOR"){
         colorsPage->setDefaultColor(value);
-    }else if(values.at(0)=="SELECTEDLOG"){
-        logsPage->setSelectedLog(value.toInt());
+    }else if(tab =="SELECTEDLOG"){        
+        i = value.toInt();
+        if (dataProxy->doesThisLogExist(i))
+        {
+        }
+        else
+        {
+            i = 1;
+            while(!dataProxy->doesThisLogExist(i))
+            {
+                i++;
+            }
+        }
+        logsPage->setSelectedLog(i);
 
+    }else if(tab =="CLUBLOGACTIVE"){
+        clubLogPage->setClubLog(value);
+    }
+    else if(tab =="CLUBLOGREALTIME"){
+        clubLogPage->setClubLogRealTime(value);
+    }
+    else if(tab =="CLUBLOGCALL"){
+        clubLogPage->setCallsign(value);
+    }
+    else if(tab =="CLUBLOGPASS"){
+        clubLogPage->setPassword(value);
+    }
+    else if(tab =="CLUBLOGEMAIL"){
+        clubLogPage->setEmail(value);
+    }
+    else if(tab =="CLUBLOGUSESTATIONCALLSIGN"){
+            clubLogPage->setUseStationCall(value);
     }else{
         //qDebug() << "SetupDialog::processConfigLine: NONE: " << endl;
     }
 
-
-
     // Lines are: Option = value;
 
 
@@ -698,13 +789,14 @@ bool SetupDialog::processConfigLine(const QString _line)
 void SetupDialog::readActiveBands (const QString actives)
 { // Checks a "10m, 12m" QString, checks if  they are valid bands and import to the
     // bands used in the program
-    //qDebug() << "SetupDialog::readActiveBands: " << actives << endl;
+   //qDebug() << "SetupDialog::readActiveBands: " << actives << endl;
 
     bool atLeastOne = false;
 
     QStringList values = actives.split(", ", QString::SkipEmptyParts);
+    QStringList _abands;
 
-    for (int i = 0; i < values.count() ; i++)
+    for (int i = 0; i < values.size() ; i++)
     {
         if (isValidBand(values.at(i)))
         {
@@ -712,14 +804,22 @@ void SetupDialog::readActiveBands (const QString actives)
             {
                 //qDebug() << "SetupDialog::readActiveBands (at least One!): " << values.at(i) << endl;
                 atLeastOne = true;
-                bands.clear();
+                _abands.clear();
             }
 
-            bands << values.at(i);
+            _abands << values.at(i);
             //qDebug() << "SetupDialog::readActiveBands: " << values.at(i) << endl;
         }
 
     }
+
+    bands.clear();
+    _abands.removeDuplicates();
+
+    bands << dataProxy->getBandsInLog(-1);
+
+    bands << _abands;
+    bands.removeDuplicates();    
 }
 
 void SetupDialog::readActiveModes (const QString actives)
@@ -727,24 +827,36 @@ void SetupDialog::readActiveModes (const QString actives)
     //qDebug() << "SetupDialog::readActiveModes: " << actives << endl;
 
     bool atLeastOne = false;
-
+    QStringList _amodes;//, _backModes;
+   // _backModes.clear();
+   // _backModes << modes;
     QStringList values = actives.split(", ", QString::SkipEmptyParts);
+    values.removeDuplicates();
 
-    for (int i = 0; i < values.count() ; i++)
+    for (int i = 0; i < values.size() ; i++)
     {
         if (isValidMode(values.at(i)))
         {
             if (!atLeastOne)
             {
                 atLeastOne = true;
-                modes.clear();
+                _amodes.clear();
             }
 
-            modes << values.at(i);
+            _amodes << values.at(i);
         }
 
     }
 
+    modes.clear();
+    modes << dataProxy->getModesInLog(-1);
+    modes << _amodes;
+    modes.removeDuplicates();
+
+
+    //qDebug() << "SetupDialog::readActiveModes: " << modes.join(" / ") << endl;
+
+
 }
 
 bool SetupDialog::isValidBand (const QString b)
@@ -770,7 +882,7 @@ bool SetupDialog::isValidMode (const QString b)
 void SetupDialog::setDefaults()
 {
     //qDebug() << "SetupDialog::setDefaults" << endl;
-    miscPage->setInMemory("TRUE");
+    //miscPage->setInMemory("TRUE");
     miscPage->setRealTime("TRUE");
     miscPage->setUTCTime("TRUE");
     miscPage->setImperial("FALSE"); //Metric system is the default
@@ -791,25 +903,37 @@ void SetupDialog::setDefaults()
     dxClusterServers.append("dxfun.com:8000");
     dxClusterServerToUse = "dxfun.com:8000";
 
+    if (modes.isEmpty())
+    {
+        modes << "SSB" << "CW" << "RTTY";
+        modes.removeDuplicates();
+    }
+
+    if (bands.isEmpty())
+    {
+        bands << "10M" << "12M" << "15M" << "17M" << "20M" << "40M" << "80M" << "160M";
+        bands.removeDuplicates();
+    }
+
 }
 
 QString SetupDialog::checkAndFixASCIIinADIF(const QString _data)
 {
     //qDebug() << "SetupDialog::checkAndFixASCIIinADIF " << _data << endl;
 //TODO: this function is also in the FileManager class. Maybe I should call that one and keep just one copy
-    int asciiVal;
+    ushort unicodeVal;
     QString st = _data;
     QString newString;
     newString.clear();
     for(int i=0; i < st.length(); i++)
     {
-    // Get ASCII VALUE into asciiVal
-        asciiVal = st.at(i).toAscii();
-        if ((32 <= asciiVal ) && (asciiVal <= 126))
+    // Get unicode VALUE into unicodeVal
+        unicodeVal = (st.at(i)).unicode();
+        if ((20 <= unicodeVal ) && (unicodeVal <= 126))
         {
             newString.append(st.at(i));
         }
-        //qDebug() << "SetupDialog::checkAndFixASCIIinADIF: " << st.at(i) <<" = " << QString::number(asciiVal) << endl;
+        //qDebug() << "SetupDialog::checkAndFixunicodeinADIF: " << st.at(i) <<" = " << QString::number(unicodeVal) << endl;
     }
 
     // Show into another lineEdit
@@ -822,3 +946,41 @@ bool SetupDialog::haveAtleastOneLog()
 {
     return dataProxy->haveAtLeastOneLog();
 }
+
+void SetupDialog::setClubLogActive(const bool _b)
+{
+    if (_b == true)
+    {
+        clubLogPage->setClubLog("True");
+    }
+    else
+    {
+        clubLogPage->setClubLog("False");
+    }
+}
+
+
+void SetupDialog::checkIfNewBandOrMode()
+{
+   //qDebug() << "SetupDialog::checkIfNewBandOrMode " << endl;
+    QStringList _items;
+
+    _items.clear();
+    //qDebug() << "SetupDialog::checkIfNewBandOrMode -1" << endl;
+    _items << dataProxy->getBandsInLog(-1);
+    //qDebug() << "SetupDialog::checkIfNewBandOrMode -2" << endl;
+    _items << (bandsModesPage->getBands()).split(", ", QString::SkipEmptyParts);
+    //qDebug() << "SetupDialog::checkIfNewBandOrMode -3" << endl;
+    _items.removeDuplicates();
+    //qDebug() << "SetupDialog::checkIfNewBandOrMode -4" << endl;
+    bandsModesPage->setActiveBands(_items);
+    //qDebug() << "SetupDialog::checkIfNewBandOrMode -5" << endl;
+
+    _items.clear();
+    _items << dataProxy->getModesInLog(-1);
+    _items << (bandsModesPage->getModes()).split(", ", QString::SkipEmptyParts);
+    _items.removeDuplicates();
+    bandsModesPage->setActiveModes(_items);
+    //qDebug() << "SetupDialog::checkIfNewBandOrMode END" << endl;
+
+}
