@@ -36,8 +36,10 @@
 #include "setuppagecolors.h"
 #include "setuppagelogs.h"
 #include "setuppageworldeditor.h"
+#include "setuppageclublog.h"
 
 #include "dataproxy_sqlite.h"
+#include "utilities.h"
 
 
 #include "locator.h"
@@ -57,6 +59,8 @@ public:
     ~SetupDialog();
 
     void setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime=true);
+    void setClubLogActive(const bool _b);
+    void checkIfNewBandOrMode();
 
 public slots:
 
@@ -85,6 +89,7 @@ private:
     void readActiveModes (const QString actives);
     bool isValidBand (const QString b);
     bool isValidMode (const QString b);
+
     QString checkAndFixASCIIinADIF(const QString _data);
     bool haveAtleastOneLog();
 
@@ -106,6 +111,7 @@ private:
     SetupPageColors *colorsPage;
     SetupPageLogs *logsPage;
     SetupPageWorldEditor *worldEditorPage;
+    SetupPageClubLog *clubLogPage;
 
     int pageRequested; // The page on the Dialog that is requested to be shown when you call it
     //QString kontestDir;
@@ -115,6 +121,7 @@ private:
     Locator *locator;
     DataProxy *dataProxy;
 
+    Utilities *util;
 };
 
 
