@@ -61,12 +61,9 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
     lastLog = 0;
 
 
-    newLogPushButton = new QPushButton(tr("New"), this);
-    //loadAllPushButton = new QPushButton(tr("Load All"), this);
-    //loadSelectedPushButton = new QPushButton(tr("Load"), this);
-    //clearPushButton = new QPushButton(tr("Clear"), this);
-    editPushButton = new QPushButton(tr("Edit"), this);
-    removePushButton = new QPushButton(tr("Remove"), this);
+    newLogPushButton = new QPushButton(tr("&New"), this);
+    editPushButton = new QPushButton(tr("&Edit"), this);
+    removePushButton = new QPushButton(tr("&Remove"), this);
 
 
     newLogPushButton->setToolTip(tr("Add a new log"));
@@ -80,12 +77,8 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
 
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
     buttonsLayout->addWidget(newLogPushButton);
-    //buttonsLayout->addWidget(loadSelectedPushButton);
-    //buttonsLayout->addWidget(loadAllPushButton);
     buttonsLayout->addWidget(editPushButton);
     buttonsLayout->addWidget(removePushButton);
-    //buttonsLayout->addWidget(clearPushButton);
-
 
     QVBoxLayout *widgetLayout = new QVBoxLayout;
     widgetLayout->addWidget(logsView);
@@ -96,12 +89,16 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
 
     setLayout(widgetLayout);
 
+    dataProxy = new DataProxy_SQLite();
+
     //connect(newLogPushButton, SIGNAL(clicked ( )), this, SLOT(slotNewButtonClicked() ) );
 
 
     createActions();
     updateSelectedLogs();
 
+
+
 }
 
 SetupPageLogs::~SetupPageLogs(){
@@ -427,10 +424,14 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     QStringList newLogq;
     newLogq.clear();
     newLogq << dateString << stationCallsign << _qs.at(4) << comment << _qs.at(12);
-    addNewLog(newLogq);
+    if (dataProxy->addNewLog(newLogq))
+    {
+        logsModel->select();
+        updateSelectedLogs();
+    }
 
 }
-
+/*
 bool SetupPageLogs::addNewLog(const QStringList _qs)
 {
     //qDebug() << "SetupPageLogs::addNewLog: " << _qs.at(2) << endl;
@@ -477,7 +478,7 @@ bool SetupPageLogs::addNewLog(const QStringList _qs)
     }
     return false;
 }
-
+*/
 void SetupPageLogs::updateSelectedLogs()
 {
     //qDebug() << "SetupPageLogs::updateSelectedLogs" << endl;
@@ -497,7 +498,7 @@ void SetupPageLogs::updateSelectedLogs()
 
 int SetupPageLogs::getSelectedLog()
 {
-    //qDebug() << "SetupPageLogs::getSelectedLog: " << currentLogs->currentText() << endl;
+   //qDebug() << "SetupPageLogs::getSelectedLog: " << currentLogs->currentText() << endl;
     QString selectedLog = currentLogs->currentText();
     int i = 0;
     QStringList qs;
