@@ -46,29 +46,32 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
 #endif
 
 
-    imperialCheckBox = new QCheckBox(tr("Imperial system"), this);
-    dbInMemory = new QCheckBox(tr("DB in Memory"), this);
-    realTimeCheckbox = new QCheckBox(tr("Log in real time"), this);
-    UTCCheckbox = new QCheckBox(tr("Time in UTC"), this);
-    alwaysADIFCheckBox = new QCheckBox(tr("Save ADIF on exit"), this);    
-    useDefaultName = new QCheckBox(tr("Use this default filename"), this);
-    sendQSLWhenRecCheckBox = new QCheckBox(tr("Mark QSO to send QSL when QSL is received"), this);
+    imperialCheckBox = new QCheckBox(tr("&Imperial system"), this);
+    //dbInMemory = new QCheckBox(tr("DB in &Memory"), this);
+    realTimeCheckbox = new QCheckBox(tr("&Log in real time"), this);
+    UTCCheckbox = new QCheckBox(tr("&Time in UTC"), this);
+    alwaysADIFCheckBox = new QCheckBox(tr("&Save ADIF on exit"), this);
+    useDefaultName = new QCheckBox(tr("Use this &default filename"), this);
+    sendQSLWhenRecCheckBox = new QCheckBox(tr("Mark &QSO to send QSL when QSL is received"), this);
+    completeWithPreviousCheckBox = new QCheckBox(tr("Complete QSO with previous data"));
+
     sendQSLWhenRecCheckBox->setToolTip(tr("QSOs will be marked to be pending to send the QSL if the DX QSL is received and you have not sent your."));
 
-    showStationCallWhenSearchCheckBox = new QCheckBox(tr("Show the Station Callsign used in the search box"), this);
+    showStationCallWhenSearchCheckBox = new QCheckBox(tr("Show the Station &Callsign used in the search box"), this);
     showStationCallWhenSearchCheckBox->setToolTip(tr("The search box will show also the callsign on the air to do the QSO."));
 
 
-    keepMyDataCheckBox = new QCheckBox(tr("Reset to My Data for all QSO"), this);
+    keepMyDataCheckBox = new QCheckBox(tr("&Reset to My Data for all QSO"), this);
     keepMyDataCheckBox->setToolTip(tr("All the data from the My Data tab will be used or data from the previous QSO will be maintained."));
 
 
     imperialCheckBox ->setToolTip(tr("Check it for Imperial system (Miles instead of Kilometres)."));
-    dbInMemory->setToolTip(tr("Working in memory (vs in file) is much quicker but you will need to save the ADIF file each time you exit KLog."));
+    //dbInMemory->setToolTip(tr("Working in memory (vs in file) is much quicker but you will need to save the ADIF file each time you exit KLog."));
     realTimeCheckbox->setToolTip(tr("Select to use real time."));
     UTCCheckbox->setToolTip(tr("Select to use UTC time."));
     alwaysADIFCheckBox->setToolTip(tr("Select if you want to save to ADIF on exit."));
     useDefaultName->setToolTip(tr("Select to use the following name for the logfile and not being asked for it anymore."));
+    completeWithPreviousCheckBox->setToolTip(tr("Complete the current QSO with previous QSO data."));
 
     defaultFileNameLineEdit = new QLineEdit;
     defaultFileNameLineEdit->setToolTip(tr("This is the default file where ADIF will be saved."));
@@ -81,6 +84,8 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     showStationCallWhenSearchCheckBox->setChecked(true);
     keepMyDataCheckBox->setChecked(true);
 
+    completeWithPreviousCheckBox->setChecked(false);
+
     fileNameButton = new QPushButton;
     fileNameButton->setToolTip(tr("Click to change the default ADIF file"));
     //TODO: Add an icon "open" to this pushbutton
@@ -100,13 +105,18 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     timeLayout->addWidget(UTCCheckbox);
     timeLayout->addWidget(realTimeCheckbox);
 
+    QHBoxLayout *dataLayout = new QHBoxLayout;
+    dataLayout->addWidget(keepMyDataCheckBox);
+    dataLayout->addWidget(completeWithPreviousCheckBox);
+
+
     //QHBoxLayout *fileOptLayout = new QHBoxLayout;
     //fileOptLayout->addWidget(useDefaultName);
     //fileOptLayout->addWidget(alwaysADIFCheckBox);
 
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
-    mainLayout->addWidget(dbInMemory);
+    //mainLayout->addWidget(dbInMemory);
     mainLayout->addLayout(fileLayout);
     mainLayout->addWidget(alwaysADIFCheckBox);
     //mainLayout->addWidget(useDefaultName);
@@ -115,7 +125,7 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     //mainLayout->addWidget(UTCCheckbox);
     mainLayout->addLayout(timeLayout);
     mainLayout->addWidget(imperialCheckBox);
-    mainLayout->addWidget(keepMyDataCheckBox);
+    mainLayout->addLayout(dataLayout);
     mainLayout->addWidget(sendQSLWhenRecCheckBox);
     mainLayout->addWidget(showStationCallWhenSearchCheckBox);
 
@@ -228,6 +238,7 @@ void SetupPageMisc::slotOpenFileButtonClicked()
 
 }
 
+/*
 QString SetupPageMisc::getInMemory()
 {
     if (dbInMemory->isChecked())
@@ -241,6 +252,7 @@ QString SetupPageMisc::getInMemory()
 
 }
 
+
 void SetupPageMisc::setInMemory(const QString t)
 {
 
@@ -253,7 +265,7 @@ void SetupPageMisc::setInMemory(const QString t)
         dbInMemory->setChecked(true);
     }
 }
-
+*/
 
 QString SetupPageMisc::getUseDefaultName()
 {
@@ -404,3 +416,28 @@ void SetupPageMisc::setKeepMyData(const QString t)
     }
 
 }
+
+QString SetupPageMisc::getCompleteWithPrevious()
+{
+    if (completeWithPreviousCheckBox->isChecked())
+    {
+        return "True";
+    }
+    else
+    {
+        return "False";
+    }
+
+}
+
+void SetupPageMisc::setCompleteWithPrevious(const QString t)
+{
+    if ( (t.toUpper()) == "FALSE")
+    {
+        completeWithPreviousCheckBox->setChecked(false);
+    }
+    else
+    {
+        completeWithPreviousCheckBox->setChecked(true);
+    }
+}
