@@ -10,14 +10,14 @@
     kontestDir = _kontestDir;
     inMemory = true;
 
-    fileOrMemoryPage = new FileOrMemoryPage();
-    ctyPage = new CTYPage(kontestDir);
+    //fileOrMemoryPage = new FileOrMemoryPage();
+    ctyPage = new CTYPage(kontestDir, version);
 
     setWizardStyle(QWizard::AeroStyle);
     setPage(Page_Intro, new IntroPage);
     setPage(Page_Lic, new LicPage);
     //setPage(Page_Mem, new FileOrMemoryPage);
-    setPage(Page_Mem, fileOrMemoryPage);
+
     setPage(Page_CTY, ctyPage);
 
 
@@ -30,7 +30,7 @@
     disconnect( cancelButton, SIGNAL( clicked() ), this, SLOT( reject() ) );
     connect(cancelButton, SIGNAL( clicked() ), this, SLOT( slotCancelWizard() ) );
 
-    connect(fileOrMemoryPage, SIGNAL(exeInMemory(bool)), this, SLOT(slotRunInMemory(bool) ) );
+    //connect(fileOrMemoryPage, SIGNAL(exeInMemory(bool)), this, SLOT(slotRunInMemory(bool) ) );
     //connect(ctyPage, SIGNAL(downloadTheFileSignal(bool)), this, SLOT(slotDownloadCTY(bool) ) );
 
   QList<QWizard::WizardButton> layout;
@@ -201,7 +201,7 @@
            "<h3> GNU GENERAL PUBLIC LICENSE</h3>"
            "<p style=text-align: center;>Version 3, 29 June 2007</p>"
 
-           "<p>Copyright  2007 Free Software Foundation, Inc.</p>"
+           "<p>Copyright (c) 2007 Free Software Foundation, Inc.</p>"
            "<p>Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.</p>"
 
            "<h3></a>Preamble</h3>"
@@ -841,7 +841,8 @@
 
  int LicPage::nextId() const
 {
-    return StartWizard::Page_Mem;
+     return StartWizard::Page_CTY;
+    //return StartWizard::Page_Mem;
 }
 
 
@@ -849,7 +850,7 @@
  {
 
  }
-
+/*
 FileOrMemoryPage::FileOrMemoryPage(QWidget *parent)
       : QWizardPage(parent)
 {
@@ -903,12 +904,13 @@ int FileOrMemoryPage::nextId() const
 {
    return StartWizard::Page_CTY;
 }
+*/
 
-CTYPage::CTYPage(const QString _kontestDir, QWidget *parent) : QWizardPage(parent)
+CTYPage::CTYPage(const QString _kontestDir, const QString _version, QWidget *parent) : QWizardPage(parent)
 {
     //completed = false;
 
-    dl = new DownLoadCTY(_kontestDir);
+    dl = new DownLoadCTY(_kontestDir, _version);
     QObject::connect(dl, SIGNAL(actionReturnDownload(int)), this, SLOT(slotDownloadFinished(int)));
     QObject::connect(dl, SIGNAL(actionShowProgres(qint64,qint64)), this, SLOT(slotUpdateDownloadProgress(qint64,qint64)));
     QObject::connect(dl, SIGNAL(actionError(int)), this, SLOT(slotDownloadError(int)));
@@ -941,15 +943,15 @@ CTYPage::CTYPage(const QString _kontestDir, QWidget *parent) : QWizardPage(paren
     ctyBrowser = new QTextEdit;
     ctyBrowser->setReadOnly(true);
 
-    QString gplLic = "<html><head>"
-            "<title>Country data needed</title>"
-            "</head><body>"
-            "<p>KLog uses the CTY.CSV file (from http://www.country-files.com/) to get the DXCC information.</p>"
-            "<p>You need to download the cty.csv file if you want KLog to show you the countries, locator, ... of the QSO you do.</p>"
-
-            "<p>Click on Download to download just now.</p>"
-            "</body></html>";
-
+    QString st = tr("Country data needed");
+    QString gplLic = "<html><head><title>";
+    gplLic = gplLic+st+"</title></head><body><p>";
+    st = tr("KLog uses the CTY.CSV file (from http://www.country-files.com/) to get the DXCC information.");
+    gplLic = gplLic + st + "</p><p>";
+    st = tr("You need to download the cty.csv file if you want KLog to show you the countries, locator, ... of the QSO you do.");
+    gplLic = gplLic + st + "</p><p>";
+    st = tr("Click on Download to download just now.");
+    gplLic = gplLic+st+"</p></body></html>";
 
    ctyBrowser->setHtml(gplLic);
 
@@ -991,37 +993,32 @@ void CTYPage::slotDownloadFinished(const int ret)
     //qDebug() << "CTYPage::slotDownloadFinished: " << QString::number(ret) << endl;
      if (ret == QNetworkReply::NoError) // No error
      {
-         progressBar->setValue(progressBar->maximum());
          hiddenCheckBox->setChecked(true);
-
+         progressBar->setEnabled(false);
+         progressBar->setValue(progressBar->maximum());
+         //hiddenCheckBox->setChecked(true);
+    //qDebug() << "CTYPage::slotDownloadFinished: (no error): " << QString::number(ret) << endl;
      }
      else if (ret == -1) // File could not be created!
      {
-
+        //qDebug() << "CTYPage::slotDownloadFinished: (file could not be created): " << QString::number(ret) << endl;
      }
      else
      {
-
+    //qDebug() << "CTYPage::slotDownloadFinished: (another result): " << QString::number(ret) << endl;
      }
 
 
 }
-/*
-bool CTYPage::isComplete()
-{
-    //tengo que reimpliementar esta funcion
-    return completed;
-}
-*/
+
 void CTYPage::slotDownloadError(const int ret)
 {
-     //qDebug() << "CTYPage::slotDownloadError: " << QString::number(ret) << endl;
+    //qDebug() << "CTYPage::slotDownloadError: " << QString::number(ret) << endl;
     int errorCode = ret;
     int i;
     progressBar->setValue(0);
     progressBar->setEnabled(false);
 
-
     if(errorCode == QNetworkReply::NoError)
     {
     }
@@ -1044,7 +1041,7 @@ void CTYPage::slotDownloadError(const int ret)
     }
     else
     {
-
+        //TODO: Add a message showing the error that has occur. errorString()?
     }
 
 }
