@@ -37,7 +37,7 @@ To insert a (key, value) pair into the hash, you can use operator[]():
 */
 World::World()
 {
-    //qDebug() << "World::World(0)" << endl;
+  //qDebug() << "World::World(0)" << endl;
 
     worldModel = new QSqlRelationalTableModel(this);
     numberOfEntities = 0;
@@ -46,6 +46,7 @@ World::World()
     kontestVersion = "";
     locator = new Locator();
     created = false;
+    dataProxy = new DataProxy_SQLite();
     //awards = new Awards();
 
 }
@@ -53,7 +54,7 @@ World::World()
 
 World::World(const QString _kontestDir)
 {
-    //qDebug() << "World::World(1): Dir" << _kontestDir << endl;
+  //qDebug() << "World::World(1): Dir" << _kontestDir << endl;
     kontestDir = _kontestDir;
     kontestVersion = "";
     worldModel = new QSqlRelationalTableModel(this);
@@ -61,67 +62,77 @@ World::World(const QString _kontestDir)
     progressBarPosition = 0;
     created = false;
     locator = new Locator();
+    dataProxy = new DataProxy_SQLite();
     //awards = new Awards();
 
 }
 
 World::World(const QString _kontestDir, const QString _kontestVer)
 {
-    //qDebug() << "World::World(2): Dir" << _kontestDir << endl;
+  //qDebug() << "World::World(2): Dir" << _kontestDir << endl;
     kontestDir = _kontestDir;
-    kontestVersion = _kontestVer;
+    kontestVersion = _kontestVer;    
     worldModel = new QSqlRelationalTableModel(this);
+   //qDebug() << "World::World(2): 1" << endl;
     numberOfEntities = 0;
     progressBarPosition = 0;
     created = false;
+   //qDebug() << "World::World(2): 2" << endl;
     locator = new Locator();
-    //awards = new Awards();
+   //qDebug() << "World::World(2): 3" << endl;
+    dataProxy = new DataProxy_SQLite();
+   //qDebug() << "World::World(2): 4" << endl;
 
 }
 
 World::~World()
 {
-    //qDebug() << "World::~World" << endl;
+   //qDebug() << "World::~World" << endl;
 }
 
 bool World::recreate(const QString _kontestDir)
 {
-    //qDebug() << "World::recreate: " << _kontestDir << endl;
+  //qDebug() << "World::recreate: " << _kontestDir << endl;
 
     QSqlQuery query;
     if (query.exec("DELETE FROM entity"))
     {
+       //qDebug() << "World::recreate: BORRADO entity"  << endl;
         if (query.exec("DELETE FROM prefixesofentity"))
         {
+           //qDebug() << "World::recreate: BORRADO prefixesofentity"  << endl;
              return create(_kontestDir);
         }
         else
         {//TODO: Manage the query error
+           //qDebug() << "World::recreate: FALLO AL BORRAR prefixesofentity"  << endl;
             return false;
         }
     }
     else
     {//TODO: Manage the query error
+       //qDebug() << "World::recreate: FALLO AL BORRAR entity"  << endl;
         return false;
     }
+   //qDebug() << "World::recreate: FIN..."  << endl;
     return false;
 }
 
 bool World::create(const QString _kontestDir)
 {
-    //qDebug() << "World::create: " << _kontestDir << endl;
+   //qDebug() << "World::create: " << _kontestDir << endl;
     kontestDir = _kontestDir;
     //qDebug() << "World::create: 2 " <<  kontestDir << endl;
     //if (readCTYDAT())
     if (readCTYCSV())
     {
         created = true;
-        //qDebug() << "World::create: TRUE"  << endl;
+       //qDebug() << "World::create: TRUE"  << endl;
 
     }else
     {
         created = false;
-        //qDebug() << "World::create: FALSE"  << endl;
+       //qDebug() << "World::create: FALSE"  << endl;
 
     }
     return created;
@@ -144,7 +155,7 @@ QStringList World::processLine(const QString _line)
 {
 
     //qDebug() << "World::processLine: received: " << _line << endl;
-    QString queryString;
+    //QString queryString;
     QStringList aa;
     QString line;
     line = (_line).simplified();
@@ -154,15 +165,10 @@ QStringList World::processLine(const QString _line)
         line.replace(QChar('\''), QChar('_'));
     }
     //qDebug() << "World::processLine: Received: " << line << endl;
-    QSqlQuery query1;
+    //QSqlQuery query1;
 
     nullValue=-1;
 
-    //queryString = QString("SELECT id FROM entity WHERE dxcc='%1'").arg(numberOfEntities);
-    //ret = query.exec(queryString);
-    //query.next();
-    //currentEntity = (query.value(0)).toInt();
-
 
     if ( (line.count(':') == 8 ) ) // First line of an Entity
     { //United States:            05:  08:  NA:   43.00:    87.90:     5.0:  K:
@@ -182,21 +188,23 @@ QStringList World::processLine(const QString _line)
         prefix = list[7];
         currentPrefix = prefix;
 
-        queryString = "SELECT id FROM continent WHERE shortname=='" + continentName + "'";        
-        query1.exec(queryString);
-        query1.next();
-        if (query1.isValid())
-        {
-            continentId = (query1.value(0)).toInt();
-        }
-        //qDebug() << "World::processLine Query: " <<  queryString << endl;
+        continentId = dataProxy->getContinentIdFromContinentShortName(continentName);
+
+        //queryString = "SELECT id FROM continent WHERE shortname=='" + continentName + "'";
+        //query1.exec(queryString);
+        //query1.next();
+        //if (query1.isValid())
+        //{
+        //    continentId = (query1.value(0)).toInt();
+        //}
+         //qDebug() << "World::processLine Query: " <<  queryString << endl;
 
 
-        //qDebug() << "World::processLine Query - Read/continenId: " << continentName << "/" << QString::number(continentId) << endl;
+         //qDebug() << "World::processLine Query - Read/continenId: " << continentName << "/" << QString::number(continentId) << endl;
 
         //queryString = QString("INSERT INTO entity (id, name, cqz, ituz, continent, latitude, longitude, utc, dxcc, mainprefix) VALUES (NULL,'%1','%2','%3','%4','%5','%6','%7','%8','%9');\n").arg(entityName).arg(cqz).arg(ituz).arg(QString::number(continentId)).arg(lat).arg(lon).arg(utc).arg(numberOfEntities).arg(prefix);
         aa << entityName << QString::number(cqz) << QString::number(ituz) <<QString::number(continentId) << QString::number(lat) << QString::number(lon) << QString::number(utc) << QString::number(numberOfEntities) << prefix;
-        //qDebug() << "World::processLine Query: " << queryString << endl;
+         //qDebug() << "World::processLine Query: " << queryString << endl;
         return aa;
         //ret = query.exec(queryString);
 
@@ -213,7 +221,7 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
     //Returns QStringList: prefix << dxcc << cqz << ituz OR CurrentEntity as a number
 
     //qDebug() << "World::processLineP: Entity/received: " << QString::number(_processingEntity) << "/" << _line << endl;
-    QString queryString;
+    //QString queryString;
     QString line;
     int currentEntity = _processingEntity;
     int _cqz, _ituz;
@@ -229,7 +237,7 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
     }
 
     //qDebug() << "World::processLineP: Received: " << line << endl;
-    QSqlQuery _queryp;
+    //QSqlQuery _queryp;
     QStringList aa, _list;
     aa.clear();
 
@@ -243,22 +251,8 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
     else if ( line.endsWith(';') ) // Last line of the Entity
     { //    =WX4TM(4),=WX5S(3)[6],=WY5I(5)[8],=WY7I(4)[7],=WY7LL(4)[7],=WZ4F(4);
         //qDebug() << "World::processLineP last line (; detected): " << line << endl;
-
-        queryString = QString("SELECT cqz FROM entity WHERE dxcc='%1'").arg(currentEntity);
-        ret = _queryp.exec(queryString);
-        _queryp.next();
-        if (_queryp.isValid())
-        {
-            _cqz = (_queryp.value(0)).toInt();
-        }
-
-        queryString = QString("SELECT ituz FROM entity WHERE dxcc='%1'").arg(currentEntity);
-        ret = _queryp.exec(queryString);
-        _queryp.next();
-        if (_queryp.isValid())
-        {
-            _ituz = (_queryp.value(0)).toInt();
-        }
+        _cqz = dataProxy->getCQzFromEntity(currentEntity);
+        _ituz = dataProxy->getITUzFromEntity(currentEntity);
 
         line = line.remove(';');
 
@@ -268,7 +262,7 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
             //aa.clear();
             aa << prefixAndZones.at(0) << QString::number(currentEntity) << prefixAndZones.at(1) << prefixAndZones.at(2);
 
-            //qDebug() << "World::processLineP Query (only one final): " << queryString << endl;
+             //qDebug() << "World::processLineP Query (only one final): " << queryString << endl;
              //readZones returns a QStringList: prefix, CQz, ITUz
              //Returns QStringList: prefix << dxcc << cqz << ituz OR CurrentEntity as a number
             return aa;
@@ -302,20 +296,9 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
     {  //    =W4KW(4),=W4LC(4),=W4LSC(3)[6],=W4LWW(4),=W4NBS(4),=W4NI(4),=W4NTI(4),
         //qDebug() << "World::processLine middle (no ; detected): " << line << endl;
 
-        queryString = QString("SELECT cqz FROM entity WHERE dxcc='%1'").arg(currentEntity);
-        ret = _queryp.exec(queryString);
-        _queryp.next();
-        if (_queryp.isValid())
-        {
-            _cqz = (_queryp.value(0)).toInt();
-        }
-        queryString = QString("SELECT ituz FROM entity WHERE dxcc='%1'").arg(currentEntity);
-        ret = _queryp.exec(queryString);
-        _queryp.next();
-        if (_queryp.isValid())
-        {
-            _ituz = (_queryp.value(0)).toInt();
-        }
+        _cqz = dataProxy->getCQzFromEntity(currentEntity);
+        _ituz = dataProxy->getITUzFromEntity(currentEntity);
+
         if (line.endsWith(','))
         {
             line.chop(1);
@@ -328,7 +311,7 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
             prefixAndZones = readZones(line, _cqz, _ituz);
             aa.clear();
             aa << prefixAndZones.at(0) << QString::number(currentEntity) << prefixAndZones.at(1) << prefixAndZones.at(2);
-            //qDebug() << "World::processLine Query (only one final): " << queryString << endl;
+             //qDebug() << "World::processLine Query (only one final): " << queryString << endl;
 
             return aa;
         }
@@ -345,15 +328,11 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
             // PROCESS THE LINE
                 prefixAndZones = readZones(list[i], _cqz, _ituz);
 
-                //queryString = queryString + QString("INSERT INTO prefixesofentity (prefix, dxcc, cqz, ituz) VALUES ('%1','%2','%3','%4');\n").arg(prefixAndZones.at(0)).arg(currentEntity).arg((prefixAndZones.at(1)).toInt()).arg((prefixAndZones.at(2)).toInt());
                 aa << prefixAndZones.at(0) << QString::number(currentEntity) << prefixAndZones.at(1) << prefixAndZones.at(2);
 
                 //ret = query.exec(queryString);
-
             }
-
-            //qDebug() << "World::processLine Query: " << queryString << endl;
-
+             //qDebug() << "World::processLine Query: " << queryString << endl;
         }
     }
     //aa.clear();
@@ -364,7 +343,7 @@ QStringList World::processLineP(const QString _line, const int _processingEntity
 QStringList World::readZones (const QString &pref, const int _cq, const int _itu)
 {
     //Returns a QStringList: prefix, CQz, ITUz
-    //qDebug() << "World::readZones: (" << pref << "/" << QString::number(_cq) <<"/" << QString::number(_itu)<< ")" << endl;
+     //qDebug() << "World::readZones: (" << pref << "/" << QString::number(_cq) <<"/" << QString::number(_itu)<< ")" << endl;
 
     QStringList result;
     int cq = _cq;
@@ -376,8 +355,10 @@ QStringList World::readZones (const QString &pref, const int _cq, const int _itu
         aux = aux.remove(0,1);
 
     }
+
     if(aux.count('[')==1) // Check if has special CQz
     {
+        //qDebug() << "World::readZones DETECTED [ !!!!" << endl;
         azone = (aux.midRef(aux.indexOf('[')+1)).toString();
         //qDebug() << "World::readZones (ITU)-1: " << aux << " right of " << QString::number(aux.indexOf('[')) << " = " << azone << endl;
         itu = (azone.left(azone.indexOf(']'))).toInt();
@@ -388,14 +369,16 @@ QStringList World::readZones (const QString &pref, const int _cq, const int _itu
 
     if(aux.count('(')==1) // Check if has special CQz
     {
+        //qDebug() << "World::readZones DETECTED ( !!!!" << endl;
         azone = (aux.midRef(aux.indexOf('(')+1)).toString();
         cq = (azone.left(azone.indexOf(')'))).toInt();
         aux = aux.left(aux.indexOf('('));
         //qDebug() << "World::readZones (CQ): "  << pref << "/" << QString::number(cq) << "/" << aux << endl;
     }
     //qDebug() << "World::readZones (Pref/CQ/ITU): "  << pref << "= " << aux <<"/" << QString::number(cq) << "/" << QString::number(itu) << endl;
+
     result << aux << QString::number(cq) << QString::number(itu);
-   //qDebug() << "World::readZones (Pref/CQ/ITU): " << result << endl;
+    //qDebug() << "World::readZones (Pref/CQ/ITU): " << result << endl;
     return result;
 
 
@@ -403,81 +386,55 @@ QStringList World::readZones (const QString &pref, const int _cq, const int _itu
 
 int World::getPrefixId(const QString _qrz)
 {
-    //qDebug() << "World::getPrefixId: " << _qrz << endl;
+    //qDebug() << "World::getPrefixId: -" << _qrz <<"-" << endl;
     //TODO: Instead of going from long to short, identify prefixes from the begining:
     // character(may be number) + number
-    int errorCode;
+
+    //int errorCode;
 
     if (_qrz.length() < 1)
     {
         return -1;
     }
     int entityID = 0;
-    int iaux1, iaux2;
+    //int iaux1, iaux2;
 
-    QString prefixl, prefixr;
-    QString queryString;
-    QSqlQuery query;
+    //QString prefixl, prefixr;
+    //QString queryString;
+    //QSqlQuery query;
 
     QString aux = changeSlashAndFindPrefix((_qrz).toUpper());
 
-    query.prepare("SELECT dxcc FROM prefixesofentity WHERE prefix==:prefix");
+    //query.prepare("SELECT dxcc FROM prefixesofentity WHERE prefix==:prefix");
 
-    QSqlDatabase::database().transaction();
+    //QSqlDatabase::database().transaction();
 
     while ((entityID <= 0) && (aux.length()>=1) )
     {
-        //qDebug() << "World::getPrefixId: Looking for the prefix in (aux): " << aux << endl;
+        entityID = dataProxy->getDXCCFromPrefix(aux);
 
+         //qDebug() << "World::getPrefixId: in the while" << aux << " = " <<  QString::number(entityID) << endl;
+         if (entityID<=0)
+         {
+             aux.chop(1);             
+         }
 
-        query.bindValue(":prefix", aux);
-        if (query.exec())
-        {}
-        else
-        {
-             errorCode = query.lastError().number();
-             //qDebug() << "World::getPrefixId - query error: " << QString::number(errorCode) << endl;
-
-        }
-
-        query.next();
-        if (query.isValid())
-        {
-            entityID = (query.value(0)).toInt();
-            //qDebug() << "World::getPrefixId - Found Entity: " << QString::number(entityID) << endl;
-        }
-        else
-        {
-
-/*
-
-                //qDebug() << "FileManager::adifReadLog: LastQuery: " << preparedQuery.lastQuery()  << endl;
-                //qDebug() << "FileManager::adifReadLog: LastError-data: " << preparedQuery.lastError().databaseText()  << endl;
-                //qDebug() << "FileManager::adifReadLog: LastError-driver: " << preparedQuery.lastError().driverText()  << endl;
-                //qDebug() << "FileManager::adifReadLog: LastError-n: " << QString::number(preparedQuery.lastError().number() ) << endl;
-
-             //qDebug() << "World::getPrefixId - value on query not valid"  << endl;
-             */
-            entityID = -1;
-            aux.chop(1);
-        }
-        //qDebug() << "World::getPrefixId: in the while" << aux << " = " <<  QString::number(entityID) << endl;
     }
 
-    QSqlDatabase::database().commit();
-    //qDebug() << "World::getPrefixId: " <<  _qrz << QString::number(entityID) << endl;
+    //QSqlDatabase::database().commit();
+     //qDebug() << "World::getPrefixId: " <<  _qrz << QString::number(entityID) << endl;
     return entityID;
 }
 
 QString World::getQRZEntityName(const QString _qrz)
 {
-    //qDebug() << "World::getQRZEntityName: " << _qrz << endl;
+     //qDebug() << "World::getQRZEntityName: " << _qrz << endl;
     if (_qrz.length() < 1 )
     {
         return "";
     }
-    QString queryString;
-    QSqlQuery query;
+    //QString queryString;
+    //QSqlQuery query;
     int prefixIDNumber = getPrefixId(_qrz);
     return getEntityName(prefixIDNumber);
 /*
@@ -519,15 +476,18 @@ QString World::getEntityName(const int _entityN)
     {
         return "";
     }
-
+    return dataProxy->getEntityNameFromId(prefixIDNumber);
+/*
     QString queryString;
     QSqlQuery query;
 
-    queryString = "SELECT name FROM entity WHERE dxcc=='" + QString::number(prefixIDNumber) +"'";
-    //qDebug() << "World::getEntityNamee: queryString-2: " << queryString << endl;
+    queryString = QString("SELECT name FROM entity WHERE (mainprefix NOT LIKE '*%') AND dxcc='%1'").arg(prefixIDNumber);
+
+    //queryString = "SELECT name FROM entity WHERE dxcc=='" + QString::number(prefixIDNumber) +"'";
+    //qDebug() << "World::getEntityName: queryString-2: " << queryString << endl;
     query.exec(queryString);
     query.next();
-    //qDebug() << "World::getEntityName end: " << _qrz << " = " << (query.value(0)).toString() << endl;
+
 
     if (query.isValid()){
         return (query.value(0)).toString();
@@ -536,19 +496,35 @@ QString World::getEntityName(const int _entityN)
     }
 
     return "";
-
+*/
 }
 
 int World::getQRZCqz(const QString _qrz)
 {
-    //qDebug() << "World::getQRZCqz: " << _qrz << endl;
-    if (_qrz.length() < 1 )
-    {
-        return -1;
-    }
+     //qDebug() << "World::getQRZCqz: " << _qrz << endl;
 
-    int prefixIdNumber = getPrefixId(_qrz);
-    return getEntityCqz(prefixIdNumber);
+     if (_qrz.length() < 1 )
+     {
+         return -1;
+     }
+
+     int i = -1;
+     QString aux = _qrz;
+
+     while ((i <= 0) && (aux.length()>=1) )
+     {
+         i = dataProxy->getCQzFromPrefix(aux);
+         if (i<=0)
+         {
+             aux.chop(1);
+         }
+     }
+     return i;
+
+
+
+    //int prefixIdNumber = getPrefixId(_qrz);
+    //return getEntityCqz(prefixIdNumber);
 
 }
 
@@ -560,11 +536,22 @@ int World::getQRZItuz(const QString _qrz)
         return -1;
     }
 
-    int prefixIdNumber = getPrefixId(_qrz);
-    return getEntityItuz(prefixIdNumber);
+    int i = -1;
+    QString aux = _qrz;
+
+    while ((i <= 0) && (aux.length()>=1) )
+    {
+        i = dataProxy->getITUzFromPrefix(aux);
+        if (i<=0)
+        {
+            aux.chop(1);
+        }
+    }
+    return i;
 
 }
 
+
 int World::getEntityCqz(const int _enti)
 {
     if (_enti < 1 )
@@ -572,9 +559,12 @@ int World::getEntityCqz(const int _enti)
         return -1;
     }
 
+    return dataProxy->getCQzFromEntity(_enti);
+/*
     QSqlQuery query;
     QString queryString;
 
+    //queryString = QString("SELECT cqz FROM prefixesofentity WHERE (mainprefix NOT LIKE '*%') AND dxcc='%1'").arg(prefixIDNumber);
     queryString = "SELECT cqz FROM prefixesofentity WHERE dxcc=='" + QString::number(_enti) +"'";
     query.exec(queryString);
     query.next();
@@ -587,16 +577,18 @@ int World::getEntityCqz(const int _enti)
     }
 
     return -1;
-
+*/
 }
 
+
 int World::getEntityItuz(const int _enti)
 {
     if (_enti < 1 )
     {
         return -1;
     }
-
+    return dataProxy->getITUzFromEntity(_enti);
+/*
     QSqlQuery query;
     QString queryString;
 
@@ -612,47 +604,24 @@ int World::getEntityItuz(const int _enti)
     }
 
     return -1;
+*/
 }
 
 int World::getQRZARRLId(const QString _qrz)
 {
-    //qDebug() << "World::getQRZARRLId" << _qrz << endl;
+     //qDebug() << "World::getQRZARRLId" << _qrz << endl;
 
     if (_qrz.length() < 1 )
     {
         return -1;
     }
 
-    QSqlQuery query;
-    QString queryString;
+    //QSqlQuery query;
+    //QString queryString;
 
     int prefixIdNumber = getPrefixId(_qrz);
     return prefixIdNumber;
-/*
-    queryString = "SELECT dxcc FROM prefixesofentity WHERE id='" + QString::number(prefixIdNumber) +"'";
-    //qDebug() << "World::getQRZARRLId QUERY: " << queryString << endl;
 
-    if (!query.exec(queryString))
-    {
-        //qDebug() << "World::getQRZARRLId: 0"  << endl;
-        return -1;
-    }
-    else
-    {
-        query.next();
-        //qDebug() << "World::getQRZARRLId: " <<_qrz << " = " <<  (query.value(0)).toInt() << endl;
-        if (query.isValid()){
-            //qDebug() << "World::getQRZARRLId: 1 (ARRLid found!)"  << endl;
-            return (query.value(0)).toInt();
-        }else{
-            //qDebug() << "World::getQRZARRLId: 2 (not found!)"  << endl;
-            return -1;
-        }
-    }
-
-    //qDebug() << "World::getQRZARRLId: 3"  << endl;
-    return -1;
-*/
 }
 
 QString World::getQRZEntityMainPrefix(const QString _qrz)
@@ -661,10 +630,14 @@ QString World::getQRZEntityMainPrefix(const QString _qrz)
     {
         return "";
     }
-
-    QString queryString;
-    QSqlQuery query;
     int i = getQRZARRLId(_qrz);
+    return getEntityMainPrefix(i);
+
+    //QString queryString;
+    //QSqlQuery query;
+
+
+/*
     queryString = "SELECT mainprefix FROM entity WHERE dxcc=='" + QString::number(i) +"'";
 
     if (!query.exec(queryString))
@@ -691,18 +664,24 @@ QString World::getQRZEntityMainPrefix(const QString _qrz)
 
 
     return "";
+*/
 }
 
+
 QString World::getEntityMainPrefix(const int _entityN)
 {
     if (_entityN <= 0 )
     {
         return "";
     }
-
+    return dataProxy->getEntityMainPrefix(_entityN);
+ /*
     QString queryString;
     QSqlQuery query;
-    queryString = "SELECT mainprefix FROM entity WHERE dxcc=='" + QString::number(_entityN) +"'";
+
+    queryString = QString("SELECT mainprefix FROM entity WHERE (mainprefix NOT LIKE '*%') AND dxcc='%1'").arg(_entityN);
+
+    //queryString = "SELECT mainprefix FROM entity WHERE dxcc=='" + QString::number(_entityN) +"'";
 
     if (!query.exec(queryString))
     {
@@ -711,7 +690,6 @@ QString World::getEntityMainPrefix(const int _entityN)
     else
     {
         query.next();
-        //qDebug() << "World::getQRZEntityMainPrefix(int): " <<_qrz << " = " <<  (query.value(0)).toInt() << endl;
 
         if (query.isValid()){
             return (query.value(0)).toString();
@@ -720,11 +698,14 @@ QString World::getEntityMainPrefix(const int _entityN)
         }
     }
     return "";
+*/
 }
 
 
 bool World::isNewCQz(const int _cqz)
 {
+    return dataProxy->isNewCQz(_cqz);
+/*
     QString queryString;
     QSqlQuery query;
     queryString = "SELECT id FROM log WHERE cqz=='" + QString::number(_cqz) +"'";
@@ -742,10 +723,9 @@ bool World::isNewCQz(const int _cqz)
         }else{
             return false;
         }
-
     }
-
     return false;
+*/
 }
 
 bool World::isNewEntity(const int _entityN)
@@ -754,7 +734,8 @@ bool World::isNewEntity(const int _entityN)
     {
         return false;
     }
-
+    return dataProxy->isNewEntity(_entityN);
+/*
     QString queryString;
     QSqlQuery query;
     queryString = "SELECT id FROM log WHERE dxcc=='" + QString::number(_entityN) +"'";
@@ -773,14 +754,13 @@ bool World::isNewEntity(const int _entityN)
             return false;
         }
     }
-
     return false;
-
+*/
 }
 
 QString World::getQRZContinentShortName(const QString _qrz)
 {
-    //qDebug() << "World::getQRZContinentShortName: " << _qrz << endl;
+     //qDebug() << "World::getQRZContinentShortName: " << _qrz << endl;
     //QString continentNumber = getQRZContinentNumber (_qrz);
     return getContinentShortName (getQRZARRLId(_qrz));
 
@@ -789,18 +769,29 @@ QString World::getQRZContinentShortName(const QString _qrz)
 
 QString World::getContinentShortName(const int _enti)
 {
-    //qDebug() << "World::getQRZContinentShortName: " << _qrz << endl;
+    //qDebug() << "World::getQRZContinentShortName: " << QString::number(_enti) << endl;
 
-    QString continentNumber = QString::number(_enti);
+    //QString continentNumber = QString::number(_enti);
 
     if ( _enti < 0 )
     {
         return "--";
     }
+    QString a = dataProxy->getContinentShortNameFromEntity(_enti);
+    if (a.length()!=2)
+    {
+        return "--";
+    }
+    else
+    {
+        return a;
+    }
 
+/*
     QString queryString;
     QSqlQuery query;
-    queryString = "SELECT continent FROM entity WHERE dxcc=='" + continentNumber +"'";
+    queryString = QString("SELECT continent FROM entity WHERE (mainprefix NOT LIKE '*%') AND dxcc='%1'").arg(_enti);
+    //queryString = "SELECT continent FROM entity WHERE dxcc=='" + continentNumber +"'";
 
     if (!query.exec(queryString))
     {
@@ -820,21 +811,23 @@ QString World::getContinentShortName(const int _enti)
     }
 
     return "--";
+*/
 }
 
 QString World::getQRZContinentNumber(const QString _qrz)
 {
     //qDebug() << "World::getQRZContinentNumber: " << _qrz << endl;
 
+    int i = getQRZARRLId(_qrz);
+    return QString::number(getContinentNumber(i));
+  /*
     QString a;
-    //if (_qrz.length()<3) // CALLS MAY BE ONLY K
-    //{
-    //    return "-1";
-    //}
     QString queryString;
     QSqlQuery query;
-    int i = getQRZARRLId(_qrz);
-    queryString = "SELECT continent FROM entity WHERE dxcc=='" + QString::number(i) +"'";
+
+    queryString = QString("SELECT continent FROM entity WHERE (mainprefix NOT LIKE '*%') AND dxcc='%1'").arg(i);
+
+    //queryString = "SELECT continent FROM entity WHERE dxcc=='" + QString::number(i) +"'";
 
 
     if (!query.exec(queryString))
@@ -857,7 +850,7 @@ QString World::getQRZContinentNumber(const QString _qrz)
         return a;
     }
     return "-1";
-
+*/
 }
 
 int World::getContinentNumber(const int _enti)
@@ -867,12 +860,15 @@ int World::getContinentNumber(const int _enti)
     {
         return -1;
     }
+    return dataProxy->getContinentIdFromEntity(_enti);
+/*
     int a = -1;
 
     QString queryString;
     QSqlQuery query;
     int i = _enti;
-    queryString = "SELECT continent FROM entity WHERE dxcc=='" + QString::number(i) +"'";
+    queryString = QString("SELECT continent FROM entity WHERE (mainprefix NOT LIKE '*%') AND dxcc='%1'").arg(i);
+    //queryString = "SELECT continent FROM entity WHERE dxcc=='" + QString::number(i) +"'";
 
 
     if (!query.exec(queryString))
@@ -882,7 +878,8 @@ int World::getContinentNumber(const int _enti)
     else
     {
         query.next();
-        if ( !(query.isValid()) ) {           
+        if ( !(query.isValid()) )
+        {
             return -1;
         }else{
             a = (query.value(0)).toInt();
@@ -908,14 +905,17 @@ int World::getContinentNumber(const int _enti)
         return a;
     }
     return -1;
-
+*/
 }
 
 double World::getQRZLongitude(const QString _qrz)
 {
+
+    int i = getQRZARRLId(_qrz);
+    return dataProxy->getLongitudeFromEntity(i);
+/*
     QString queryString;
     QSqlQuery query;
-    int i = getQRZARRLId(_qrz);
     queryString = "SELECT longitude FROM entity WHERE dxcc=='" + QString::number(i) +"'";
 
 
@@ -937,6 +937,7 @@ double World::getQRZLongitude(const QString _qrz)
 
     }
     return 0.0;
+*/
 }
 
 double World::getLongitude(const int _enti)
@@ -945,10 +946,15 @@ double World::getLongitude(const int _enti)
     {
         return 0.0;
     }
+
+    return dataProxy->getLongitudeFromEntity(_enti);
+
+
+/*
+
     QString queryString;
     QSqlQuery query;
 
-
     int i = _enti;
     queryString = "SELECT longitude FROM entity WHERE dxcc=='" + QString::number(i) +"'";
 
@@ -971,15 +977,17 @@ double World::getLongitude(const int _enti)
 
     }
     return 0.0;
+*/
 }
 
 double World::getQRZLatitude(const QString _qrz)
 {
 
-
+    int i = getQRZARRLId(_qrz);
+    return dataProxy->getLatitudeFromEntity(i);
+ /*
     QString queryString;
     QSqlQuery query;
-    int i = getQRZARRLId(_qrz);
     queryString = "SELECT latitude FROM entity WHERE dxcc=='" + QString::number(i) +"'";
 
 
@@ -1001,7 +1009,7 @@ double World::getQRZLatitude(const QString _qrz)
     }
 
     return 0.0;
-
+*/
 }
 
 double World::getLatitude(const int _enti)
@@ -1010,7 +1018,9 @@ double World::getLatitude(const int _enti)
     {
         return 0.0;
     }
+    return dataProxy->getLatitudeFromEntity(_enti);
 
+/*
     QString queryString;
     QSqlQuery query;
     int i = _enti;
@@ -1035,7 +1045,7 @@ double World::getLatitude(const int _enti)
     }
 
     return 0.0;
-
+*/
 }
 
 QString World::getQRZLocator(const QString _qrz)
@@ -1056,7 +1066,7 @@ QString World::getLocator(const int _enti)
     return locator->getLocator(getLongitude(_enti), getLatitude(_enti));
 }
 
-
+/*
 int World::getBandIdFromFreq(const QString fr)
 {
     //qDebug() << "World::getBandIdFromFreq: " << fr  << endl;
@@ -1091,61 +1101,20 @@ int World::getBandIdFromFreq(const QString fr)
 
     return -1;
 }
+*/
 
 
 
 QString World::getQRZEntityPrefixes(const QString _qrz)
 {
-    QString result;
-    result = "";
-    QString queryString;
-    QSqlQuery query;
+
     int i = getQRZARRLId(_qrz);
-    queryString = "SELECT prefix FROM prefixesofentity WHERE dxcc=='" + QString::number(i) +"'";
-
-
-    if (!query.exec(queryString))
-    {
-        return "";
-    }
-    else
-    {
-        while ( (query.next())) {
-            if (query.isValid())
-            {
-                result = result + ", " + (query.value(0)).toString();
-            }
-            else
-            {
-            }
-        }
-
-        if (result.length() < 1)
-        {
-            return result;
-        }
-        else
-        {
-            result = result.remove(0,2);
-            return result;
-        }
-    }
-
-    return "";
-}
-
-QString World::getEntityPrefixes(const int _enti)
-{
-    if (_enti<=0)
-    {
-        return "";
-
-    }
+    return dataProxy->getEntityMainPrefix(i);
+/*
     QString result;
     result = "";
     QString queryString;
     QSqlQuery query;
-    int i = _enti;
     queryString = "SELECT prefix FROM prefixesofentity WHERE dxcc=='" + QString::number(i) +"'";
 
 
@@ -1177,9 +1146,12 @@ QString World::getEntityPrefixes(const int _enti)
     }
 
     return "";
+*/
 }
 
 
+
+
 bool World::readCTYDAT()
 {
     //qDebug() << "World::readCTYDAT(): " << kontestDir << endl;
@@ -1250,7 +1222,7 @@ bool World::readCTYDAT()
         stringList.clear();
         stringList << processLine(file.readLine());
 
-        if (stringList.count()==9 )
+        if (stringList.size()==9 )
         {
 
             query.addBindValue(QVariant(QVariant::Int));
@@ -1368,7 +1340,7 @@ bool World::readCTYDAT()
 
 bool World::readCTYCSV()
 {
-    //qDebug() << "World::readCTYCSV(): " << kontestDir << endl;
+   //qDebug() << "World::readCTYCSV(): " << kontestDir << endl;
 
     QString tq;
     QString fileName;
@@ -1396,7 +1368,7 @@ bool World::readCTYCSV()
     }
     else
     {
-       // //qDebug() << "World::readCTYCSV() File found: " << fileName << endl;
+       //qDebug() << "World::readCTYCSV() File found: " << fileName << endl;
     }
     beginingOfFile = file.pos();
 
@@ -1431,7 +1403,7 @@ bool World::readCTYCSV()
 
     QSqlDatabase::database().transaction();
 
-    QStringList stringList, stringListPrefixes;
+    QStringList stringList, stringListPrefixes, stringListProcessedPrefix;
 
 
 
@@ -1454,7 +1426,7 @@ bool World::readCTYCSV()
 
         stringList << tq.split(',');
 
-        if (stringList.count()>=8 )
+        if (stringList.size()>=8 )
         {
 
 //(id, name, cqz, ituz, continent, latitude, longitude, utc, dxcc, mainprefix)
@@ -1500,7 +1472,7 @@ bool World::readCTYCSV()
 
             }
 
-            if (stringList.count()>8)
+            if (stringList.size()>8)
             {
                 tq = stringList.at(9);
                 stringListPrefixes << tq.split(' ');
@@ -1510,21 +1482,32 @@ bool World::readCTYCSV()
                 for (int i = 0; i < stringListPrefixes.size(); ++i)
                 {
                     prefAux = stringListPrefixes.at(i);
-                 //queryP.prepare("INSERT INTO prefixesofentity (id, prefix, dxcc, cqz, ituz) VALUES (?, ?, ?, ?, ?)");
-                    //                                            0    1       2    3    4
+                    //queryP.prepare("INSERT INTO prefixesofentity (id, prefix, dxcc, cqz, ituz) VALUES (?, ?, ?, ?, ?)");
+                    //                                               0    1       2    3    4
                     //  (id, prefix, dxcc, cqz, ituz)
-                    //qDebug()  << "World::readCTYCSV(): Prefix: " << stringListPrefixes.at(i) << endl;
+                     //qDebug()  << "World::readCTYCSV(): Prefix: " << stringListPrefixes.at(i) << endl;
                     queryP.addBindValue(QVariant(QVariant::Int));
 
+
+                    //readZones (const QString &pref, const int _cq, const int _itu)
+                    //Returns a QStringList: prefix, CQz, ITUz
+                    stringListProcessedPrefix.clear();
+                    stringListProcessedPrefix << readZones(prefAux, (stringList.at(4)).toInt(), (stringList.at(5)).toInt());
+
                     if (prefAux.at(0)=='=')
                     { //TODO: Maybe there is a better way to identify exact calls instead of prefixes , identified with a = before he call.
                         prefAux.remove(0,1);
                     }
 
-                    queryP.addBindValue(prefAux);
+                    //queryP.addBindValue(prefAux);
+                    queryP.addBindValue(stringListProcessedPrefix.at(0));
+                    //queryP.addBindValue(stringList.at(2));
+                    //queryP.addBindValue(stringList.at(4));
+                    //queryP.addBindValue(stringList.at(5));
+
                     queryP.addBindValue(stringList.at(2));
-                    queryP.addBindValue(stringList.at(4));
-                    queryP.addBindValue(stringList.at(5));
+                    queryP.addBindValue(stringListProcessedPrefix.at(1));
+                    queryP.addBindValue(stringListProcessedPrefix.at(2));
 
                     if (queryP.exec())
                     {
@@ -1563,6 +1546,7 @@ bool World::readCTYCSV()
 
 QString World::changeSlashAndFindPrefix(const QString _qrz)
 {
+    //qDebug() << "World::changeSlashAndFindPrefix: -"  << _qrz <<"-" << endl;
     int iaux1, iaux2;
 
     QString aux = _qrz.toUpper();
@@ -1584,7 +1568,7 @@ QString World::changeSlashAndFindPrefix(const QString _qrz)
             aux.remove(aux.length()-1,1);
         }
         iaux1 = aux.indexOf('/');
-        //qDebug() << "World::changeSlashAndFindPrefix: Slash found at: "  << QString::number(iaux1) << endl;
+         //qDebug() << "World::changeSlashAndFindPrefix: Slash found at: "  << QString::number(iaux1) << endl;
 
         iaux2 = (aux.length())- iaux1; // iaux2 is the length of the second part
         if (iaux2 < 0){
@@ -1605,7 +1589,7 @@ QString World::changeSlashAndFindPrefix(const QString _qrz)
 
 bool World::checkQRZValidFormat(const QString _qrz)
 {
-    //qDebug()  << "World::checkQRZValidFormat: " << _qrz << endl;
+     //qDebug()  << "World::checkQRZValidFormat: -" << _qrz <<"-" << endl;
 
     QString aux = changeSlashAndFindPrefix(_qrz.toUpper());
 
@@ -1694,42 +1678,16 @@ bool World::checkQRZValidFormat(const QString _qrz)
     {
         suffix = suffix + aux.at(i);
     }
-    //qDebug()  << "World::checkQRZValidFormat: Prefix = " << prefix << endl;
-    //qDebug()  << "World::checkQRZValidFormat: Separator = " << separator << endl;
-    //qDebug()  << "World::checkQRZValidFormat: Suffix = " << suffix << endl;
-    //qDebug()  << "World::checkQRZValidFormat: Call = " << prefix+separator+suffix << endl;
+     //qDebug()  << "World::checkQRZValidFormat: Prefix = " << prefix << endl;
+     //qDebug()  << "World::checkQRZValidFormat: Separator = " << separator << endl;
+     //qDebug()  << "World::checkQRZValidFormat: Suffix = " << suffix << endl;
+     //qDebug()  << "World::checkQRZValidFormat: Call = " << prefix+separator+suffix << endl;
     return true;
 }
 
 QStringList World::getEntitiesNames()
 {
     //qDebug()  << "World::getEntitiesNames"  << endl;
-    QString aux = QString();
-    QStringList qs;
-    qs.clear();
-    QString stringQuery = QString("SELECT mainprefix, name, dxcc FROM entity");
-    QSqlQuery query;
-
-    if (query.exec(stringQuery))
-    {
-        while ( (query.next())) {
-            if (query.isValid())
-            {
-                aux.clear();
-                aux = (query.value(0)).toString() + "-" + (query.value(1)).toString()+" ("+(query.value(2)).toString()+")";
-                //result = result + ", " + (query.value(0)).toString();
-                qs << aux;
-            }
-            else
-            {
-            }
-        }
-
-    }
-    else
-    {
-
-    }
-    return qs;
+     return dataProxy->getEntitiesNames();
 }
 
