@@ -9,20 +9,20 @@
  ***************************************************************************/
 
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify        *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
 
@@ -39,6 +39,8 @@
 #include <QtDebug>
 
 #include "locator.h"
+#include "dataproxy.h"
+#include "dataproxy_sqlite.h"
 //#include "awards.h"
 
 
@@ -53,6 +55,7 @@ enum
 class World : public QWidget
 {
     //friend class Awards;
+    Q_OBJECT
 
 public:
     World();
@@ -84,8 +87,10 @@ public:
     double getQRZLatitude(const QString _qrz); // Returns the latitude of the Entity
     double getLatitude(const int _enti); // Returns the latitude of the Entity
 
-    int getQRZCqz(const QString _qrz);
+
     int getEntityCqz(const int _enti);
+    int getQRZCqz(const QString _qrz);
+    //int getPrefixCQz(const QString _p);
 
     int getQRZItuz(const QString _qrz);
     int getEntityItuz(const int _enti);
@@ -93,7 +98,7 @@ public:
     int getQRZARRLId(const QString _qrz); //Returns the ARRL id of the Entity from a QRZ & Returns -1 if not found.
     bool isNewCQz(const int _cqz);
     bool isNewEntity(const int _entityN);
-    int getBandIdFromFreq(const QString fr);
+    //int getBandIdFromFreq(const QString fr);
 
     QString getQRZEntityPrefixes(const QString _qrz);
     QString getEntityPrefixes(const int _enti);
@@ -136,6 +141,7 @@ private:
     //QProgressBar *progressBar;
 
     Locator *locator;
+    DataProxy *dataProxy;
     //Awards *awards;
 
 };
